# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waBotMetadata/WAWebProtobufsBotMetadata.proto
# Protobuf Python Version: 6.30.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    2,
    '',
    'waBotMetadata/WAWebProtobufsBotMetadata.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from waCommon import WACommon_pb2 as waCommon_dot_WACommon__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-waBotMetadata/WAWebProtobufsBotMetadata.proto\x12\x19WAWebProtobufsBotMetadata\x1a\x17waCommon/WACommon.proto\"\xb5\x05\n\x11\x42otPluginMetadata\x12M\n\x08provider\x18\x01 \x01(\x0e\x32;.WAWebProtobufsBotMetadata.BotPluginMetadata.SearchProvider\x12K\n\npluginType\x18\x02 \x01(\x0e\x32\x37.WAWebProtobufsBotMetadata.BotPluginMetadata.PluginType\x12\x17\n\x0fthumbnailCDNURL\x18\x03 \x01(\t\x12\x1a\n\x12profilePhotoCDNURL\x18\x04 \x01(\t\x12\x19\n\x11searchProviderURL\x18\x05 \x01(\t\x12\x16\n\x0ereferenceIndex\x18\x06 \x01(\r\x12\x1a\n\x12\x65xpectedLinksCount\x18\x07 \x01(\r\x12\x13\n\x0bsearchQuery\x18\t \x01(\t\x12\x34\n\x16parentPluginMessageKey\x18\n \x01(\x0b\x32\x14.WACommon.MessageKey\x12P\n\x0f\x64\x65precatedField\x18\x0b \x01(\x0e\x32\x37.WAWebProtobufsBotMetadata.BotPluginMetadata.PluginType\x12Q\n\x10parentPluginType\x18\x0c \x01(\x0e\x32\x37.WAWebProtobufsBotMetadata.BotPluginMetadata.PluginType\x12\x15\n\rfaviconCDNURL\x18\r \x01(\t\"7\n\nPluginType\x12\x12\n\x0eUNKNOWN_PLUGIN\x10\x00\x12\t\n\x05REELS\x10\x01\x12\n\n\x06SEARCH\x10\x02\"@\n\x0eSearchProvider\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04\x42ING\x10\x01\x12\n\n\x06GOOGLE\x10\x02\x12\x0b\n\x07SUPPORT\x10\x03\"\x9a\x01\n\x10\x42otLinkedAccount\x12N\n\x04type\x18\x01 \x01(\x0e\x32@.WAWebProtobufsBotMetadata.BotLinkedAccount.BotLinkedAccountType\"6\n\x14\x42otLinkedAccountType\x12\x1e\n\x1a\x42OT_LINKED_ACCOUNT_TYPE_1P\x10\x00\"\xf1\x01\n$BotSignatureVerificationUseCaseProof\x12\x0f\n\x07version\x18\x01 \x01(\x05\x12\x64\n\x07useCase\x18\x02 \x01(\x0e\x32S.WAWebProtobufsBotMetadata.BotSignatureVerificationUseCaseProof.BotSignatureUseCase\x12\x11\n\tsignature\x18\x03 \x01(\x0c\x12\x18\n\x10\x63\x65rtificateChain\x18\x04 \x01(\x0c\"%\n\x13\x42otSignatureUseCase\x12\x0e\n\nWA_BOT_MSG\x10\x00\"\xc1\x01\n\x1b\x42otPromotionMessageMetadata\x12^\n\rpromotionType\x18\x01 \x01(\x0e\x32G.WAWebProtobufsBotMetadata.BotPromotionMessageMetadata.BotPromotionType\x12\x13\n\x0b\x62uttonTitle\x18\x02 \x01(\t\"-\n\x10\x42otPromotionType\x12\x10\n\x0cUNKNOWN_TYPE\x10\x00\x12\x07\n\x03\x43\x35\x30\x10\x01\"\x9a\x02\n\x10\x42otMediaMetadata\x12\x12\n\nfileSHA256\x18\x01 \x01(\t\x12\x10\n\x08mediaKey\x18\x02 \x01(\t\x12\x15\n\rfileEncSHA256\x18\x03 \x01(\t\x12\x12\n\ndirectPath\x18\x04 \x01(\t\x12\x19\n\x11mediaKeyTimestamp\x18\x05 \x01(\x03\x12\x10\n\x08mimetype\x18\x06 \x01(\t\x12T\n\x0forientationType\x18\x07 \x01(\x0e\x32;.WAWebProtobufsBotMetadata.BotMediaMetadata.OrientationType\"2\n\x0fOrientationType\x12\n\n\x06\x43\x45NTER\x10\x01\x12\x08\n\x04LEFT\x10\x02\x12\t\n\x05RIGHT\x10\x03\"\xa9\x03\n\x13\x42otReminderMetadata\x12/\n\x11requestMessageKey\x18\x01 \x01(\x0b\x32\x14.WACommon.MessageKey\x12M\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32=.WAWebProtobufsBotMetadata.BotReminderMetadata.ReminderAction\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x1c\n\x14nextTriggerTimestamp\x18\x04 \x01(\x04\x12S\n\tfrequency\x18\x05 \x01(\x0e\x32@.WAWebProtobufsBotMetadata.BotReminderMetadata.ReminderFrequency\"O\n\x11ReminderFrequency\x12\x08\n\x04ONCE\x10\x01\x12\t\n\x05\x44\x41ILY\x10\x02\x12\n\n\x06WEEKLY\x10\x03\x12\x0c\n\x08\x42IWEEKLY\x10\x04\x12\x0b\n\x07MONTHLY\x10\x05\"@\n\x0eReminderAction\x12\n\n\x06NOTIFY\x10\x01\x12\n\n\x06\x43REATE\x10\x02\x12\n\n\x06\x44\x45LETE\x10\x03\x12\n\n\x06UPDATE\x10\x04\"\xd0\x02\n\x10\x42otModelMetadata\x12H\n\tmodelType\x18\x01 \x01(\x0e\x32\x35.WAWebProtobufsBotMetadata.BotModelMetadata.ModelType\x12Z\n\x12premiumModelStatus\x18\x02 \x01(\x0e\x32>.WAWebProtobufsBotMetadata.BotModelMetadata.PremiumModelStatus\"O\n\x12PremiumModelStatus\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\r\n\tAVAILABLE\x10\x01\x12\x16\n\x12QUOTA_EXCEED_LIMIT\x10\x02\"E\n\tModelType\x12\x10\n\x0cUNKNOWN_TYPE\x10\x00\x12\x0e\n\nLLAMA_PROD\x10\x01\x12\x16\n\x12LLAMA_PROD_PREMIUM\x10\x02\"\xab\x0c\n\x1c\x42otProgressIndicatorMetadata\x12\x1b\n\x13progressDescription\x18\x01 \x01(\t\x12\x66\n\rstepsMetadata\x18\x02 \x03(\x0b\x32O.WAWebProtobufsBotMetadata.BotProgressIndicatorMetadata.BotPlanningStepMetadata\x1a\x85\x0b\n\x17\x42otPlanningStepMetadata\x12\x13\n\x0bstatusTitle\x18\x01 \x01(\t\x12\x12\n\nstatusBody\x18\x02 \x01(\t\x12\x89\x01\n\x0fsourcesMetadata\x18\x03 \x03(\x0b\x32p.WAWebProtobufsBotMetadata.BotProgressIndicatorMetadata.BotPlanningStepMetadata.BotPlanningSearchSourcesMetadata\x12r\n\x06status\x18\x04 \x01(\x0e\x32\x62.WAWebProtobufsBotMetadata.BotProgressIndicatorMetadata.BotPlanningStepMetadata.PlanningStepStatus\x12\x13\n\x0bisReasoning\x18\x05 \x01(\x08\x12\x18\n\x10isEnhancedSearch\x18\x06 \x01(\x08\x12\x80\x01\n\x08sections\x18\x07 \x03(\x0b\x32n.WAWebProtobufsBotMetadata.BotProgressIndicatorMetadata.BotPlanningStepMetadata.BotPlanningStepSectionMetadata\x1a\xc1\x02\n BotPlanningSearchSourcesMetadata\x12\x13\n\x0bsourceTitle\x18\x01 \x01(\t\x12\xa3\x01\n\x08provider\x18\x02 \x01(\x0e\x32\x90\x01.WAWebProtobufsBotMetadata.BotProgressIndicatorMetadata.BotPlanningStepMetadata.BotPlanningSearchSourcesMetadata.BotPlanningSearchSourceProvider\x12\x11\n\tsourceURL\x18\x03 \x01(\t\"O\n\x1f\x42otPlanningSearchSourceProvider\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05OTHER\x10\x01\x12\n\n\x06GOOGLE\x10\x02\x12\x08\n\x04\x42ING\x10\x03\x1a\xd6\x01\n\x1e\x42otPlanningStepSectionMetadata\x12\x14\n\x0csectionTitle\x18\x01 \x01(\t\x12\x13\n\x0bsectionBody\x18\x02 \x01(\t\x12\x88\x01\n\x0fsourcesMetadata\x18\x03 \x03(\x0b\x32o.WAWebProtobufsBotMetadata.BotProgressIndicatorMetadata.BotPlanningStepMetadata.BotPlanningSearchSourceMetadata\x1a\xd2\x01\n\x1f\x42otPlanningSearchSourceMetadata\x12\r\n\x05title\x18\x01 \x01(\t\x12y\n\x08provider\x18\x02 \x01(\x0e\x32g.WAWebProtobufsBotMetadata.BotProgressIndicatorMetadata.BotPlanningStepMetadata.BotSearchSourceProvider\x12\x11\n\tsourceURL\x18\x03 \x01(\t\x12\x12\n\nfavIconURL\x18\x04 \x01(\t\"P\n\x17\x42otSearchSourceProvider\x12\x14\n\x10UNKNOWN_PROVIDER\x10\x00\x12\t\n\x05OTHER\x10\x01\x12\n\n\x06GOOGLE\x10\x02\x12\x08\n\x04\x42ING\x10\x03\"K\n\x12PlanningStepStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07PLANNED\x10\x01\x12\r\n\tEXECUTING\x10\x02\x12\x0c\n\x08\x46INISHED\x10\x03\"\xaf\n\n\x15\x42otCapabilityMetadata\x12X\n\x0c\x63\x61pabilities\x18\x01 \x03(\x0e\x32\x42.WAWebProtobufsBotMetadata.BotCapabilityMetadata.BotCapabilityType\"\xbb\t\n\x11\x42otCapabilityType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x16\n\x12PROGRESS_INDICATOR\x10\x01\x12\x19\n\x15RICH_RESPONSE_HEADING\x10\x02\x12\x1d\n\x19RICH_RESPONSE_NESTED_LIST\x10\x03\x12\r\n\tAI_MEMORY\x10\x04\x12 \n\x1cRICH_RESPONSE_THREAD_SURFING\x10\x05\x12\x17\n\x13RICH_RESPONSE_TABLE\x10\x06\x12\x16\n\x12RICH_RESPONSE_CODE\x10\x07\x12%\n!RICH_RESPONSE_STRUCTURED_RESPONSE\x10\x08\x12\x1e\n\x1aRICH_RESPONSE_INLINE_IMAGE\x10\t\x12#\n\x1fWA_IG_1P_PLUGIN_RANKING_CONTROL\x10\n\x12$\n WA_IG_1P_PLUGIN_RANKING_UPDATE_1\x10\x0b\x12$\n WA_IG_1P_PLUGIN_RANKING_UPDATE_2\x10\x0c\x12$\n WA_IG_1P_PLUGIN_RANKING_UPDATE_3\x10\r\x12$\n WA_IG_1P_PLUGIN_RANKING_UPDATE_4\x10\x0e\x12$\n WA_IG_1P_PLUGIN_RANKING_UPDATE_5\x10\x0f\x12$\n WA_IG_1P_PLUGIN_RANKING_UPDATE_6\x10\x10\x12$\n WA_IG_1P_PLUGIN_RANKING_UPDATE_7\x10\x11\x12$\n WA_IG_1P_PLUGIN_RANKING_UPDATE_8\x10\x12\x12$\n WA_IG_1P_PLUGIN_RANKING_UPDATE_9\x10\x13\x12%\n!WA_IG_1P_PLUGIN_RANKING_UPDATE_10\x10\x14\x12\x1d\n\x19RICH_RESPONSE_SUB_HEADING\x10\x15\x12\x1c\n\x18RICH_RESPONSE_GRID_IMAGE\x10\x16\x12\x18\n\x14\x41I_STUDIO_UGC_MEMORY\x10\x17\x12\x17\n\x13RICH_RESPONSE_LATEX\x10\x18\x12\x16\n\x12RICH_RESPONSE_MAPS\x10\x19\x12\x1e\n\x1aRICH_RESPONSE_INLINE_REELS\x10\x1a\x12\x14\n\x10\x41GENTIC_PLANNING\x10\x1b\x12\x13\n\x0f\x41\x43\x43OUNT_LINKING\x10\x1c\x12\x1c\n\x18STREAMING_DISAGGREGATION\x10\x1d\x12\x1f\n\x1bRICH_RESPONSE_GRID_IMAGE_3P\x10\x1e\x12\x1e\n\x1aRICH_RESPONSE_LATEX_INLINE\x10\x1f\x12\x0e\n\nQUERY_PLAN\x10 \x12\x15\n\x11PROACTIVE_MESSAGE\x10!\x12\"\n\x1eRICH_RESPONSE_UNIFIED_RESPONSE\x10\"\x12\x15\n\x11PROMOTION_MESSAGE\x10#\x12\x1b\n\x17SIMPLIFIED_PROFILE_PAGE\x10$\x12$\n RICH_RESPONSE_SOURCES_IN_MESSAGE\x10%\x12%\n!RICH_RESPONSE_SIDE_BY_SIDE_SURVEY\x10&\"\xb0\x01\n\x18\x42otModeSelectionMetadata\x12V\n\x04mode\x18\x01 \x03(\x0e\x32H.WAWebProtobufsBotMetadata.BotModeSelectionMetadata.BotUserSelectionMode\"<\n\x14\x42otUserSelectionMode\x12\x10\n\x0cUNKNOWN_MODE\x10\x00\x12\x12\n\x0eREASONING_MODE\x10\x01\"\xf0\x02\n\x10\x42otQuotaMetadata\x12\x64\n\x17\x62otFeatureQuotaMetadata\x18\x01 \x03(\x0b\x32\x43.WAWebProtobufsBotMetadata.BotQuotaMetadata.BotFeatureQuotaMetadata\x1a\xf5\x01\n\x17\x42otFeatureQuotaMetadata\x12g\n\x0b\x66\x65\x61tureType\x18\x01 \x01(\x0e\x32R.WAWebProtobufsBotMetadata.BotQuotaMetadata.BotFeatureQuotaMetadata.BotFeatureType\x12\x16\n\x0eremainingQuota\x18\x02 \x01(\r\x12\x1b\n\x13\x65xpirationTimestamp\x18\x03 \x01(\x04\"<\n\x0e\x42otFeatureType\x12\x13\n\x0fUNKNOWN_FEATURE\x10\x00\x12\x15\n\x11REASONING_FEATURE\x10\x01\"\xac\x01\n\x12\x42otImagineMetadata\x12N\n\x0bimagineType\x18\x01 \x01(\x0e\x32\x39.WAWebProtobufsBotMetadata.BotImagineMetadata.ImagineType\"F\n\x0bImagineType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07IMAGINE\x10\x01\x12\x08\n\x04MEMU\x10\x02\x12\t\n\x05\x46LASH\x10\x03\x12\x08\n\x04\x45\x44IT\x10\x04\"\xac\x03\n\x12\x42otSourcesMetadata\x12L\n\x07sources\x18\x01 \x03(\x0b\x32;.WAWebProtobufsBotMetadata.BotSourcesMetadata.BotSourceItem\x1a\xc7\x02\n\rBotSourceItem\x12\\\n\x08provider\x18\x01 \x01(\x0e\x32J.WAWebProtobufsBotMetadata.BotSourcesMetadata.BotSourceItem.SourceProvider\x12\x17\n\x0fthumbnailCDNURL\x18\x02 \x01(\t\x12\x19\n\x11sourceProviderURL\x18\x03 \x01(\t\x12\x13\n\x0bsourceQuery\x18\x04 \x01(\t\x12\x15\n\rfaviconCDNURL\x18\x05 \x01(\t\x12\x16\n\x0e\x63itationNumber\x18\x06 \x01(\r\x12\x13\n\x0bsourceTitle\x18\x07 \x01(\t\"K\n\x0eSourceProvider\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04\x42ING\x10\x01\x12\n\n\x06GOOGLE\x10\x02\x12\x0b\n\x07SUPPORT\x10\x03\x12\t\n\x05OTHER\x10\x04\"\xa4\x01\n\x10\x42otMessageOrigin\x12N\n\x04type\x18\x01 \x01(\x0e\x32@.WAWebProtobufsBotMetadata.BotMessageOrigin.BotMessageOriginType\"@\n\x14\x42otMessageOriginType\x12(\n$BOT_MESSAGE_ORIGIN_TYPE_AI_INITIATED\x10\x00\"s\n\x11\x42otAvatarMetadata\x12\x11\n\tsentiment\x18\x01 \x01(\r\x12\x15\n\rbehaviorGraph\x18\x02 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x03 \x01(\r\x12\x11\n\tintensity\x18\x04 \x01(\r\x12\x11\n\twordCount\x18\x05 \x01(\r\"\xb9\x01\n\x1a\x42otSuggestedPromptMetadata\x12\x18\n\x10suggestedPrompts\x18\x01 \x03(\t\x12\x1b\n\x13selectedPromptIndex\x18\x02 \x01(\r\x12J\n\x11promptSuggestions\x18\x03 \x01(\x0b\x32/.WAWebProtobufsBotMetadata.BotPromptSuggestions\x12\x18\n\x10selectedPromptID\x18\x04 \x01(\t\"[\n\x14\x42otPromptSuggestions\x12\x43\n\x0bsuggestions\x18\x01 \x03(\x0b\x32..WAWebProtobufsBotMetadata.BotPromptSuggestion\"7\n\x13\x42otPromptSuggestion\x12\x0e\n\x06prompt\x18\x01 \x01(\t\x12\x10\n\x08promptID\x18\x02 \x01(\t\"\x85\x01\n\x19\x42otLinkedAccountsMetadata\x12=\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32+.WAWebProtobufsBotMetadata.BotLinkedAccount\x12\x14\n\x0c\x61\x63\x41uthTokens\x18\x02 \x01(\x0c\x12\x13\n\x0b\x61\x63\x45rrorCode\x18\x03 \x01(\x05\"\xa5\x01\n\x11\x42otMemoryMetadata\x12<\n\naddedFacts\x18\x01 \x03(\x0b\x32(.WAWebProtobufsBotMetadata.BotMemoryFact\x12>\n\x0cremovedFacts\x18\x02 \x03(\x0b\x32(.WAWebProtobufsBotMetadata.BotMemoryFact\x12\x12\n\ndisclaimer\x18\x03 \x01(\t\"-\n\rBotMemoryFact\x12\x0c\n\x04\x66\x61\x63t\x18\x01 \x01(\t\x12\x0e\n\x06\x66\x61\x63tID\x18\x02 \x01(\t\"s\n BotSignatureVerificationMetadata\x12O\n\x06proofs\x18\x01 \x03(\x0b\x32?.WAWebProtobufsBotMetadata.BotSignatureVerificationUseCaseProof\"\x96\x01\n\x14\x42otRenderingMetadata\x12I\n\x08keywords\x18\x01 \x03(\x0b\x32\x37.WAWebProtobufsBotMetadata.BotRenderingMetadata.Keyword\x1a\x33\n\x07Keyword\x12\r\n\x05value\x18\x01 \x01(\t\x12\x19\n\x11\x61ssociatedPrompts\x18\x02 \x03(\t\"\xc8\x01\n\x12\x42otMetricsMetadata\x12\x15\n\rdestinationID\x18\x01 \x01(\t\x12N\n\x15\x64\x65stinationEntryPoint\x18\x02 \x01(\x0e\x32/.WAWebProtobufsBotMetadata.BotMetricsEntryPoint\x12K\n\x0cthreadOrigin\x18\x03 \x01(\x0e\x32\x35.WAWebProtobufsBotMetadata.BotMetricsThreadEntryPoint\"k\n\x12\x42otSessionMetadata\x12\x11\n\tsessionID\x18\x01 \x01(\t\x12\x42\n\rsessionSource\x18\x02 \x01(\x0e\x32+.WAWebProtobufsBotMetadata.BotSessionSource\"R\n\x0f\x42otMemuMetadata\x12?\n\nfaceImages\x18\x01 \x03(\x0b\x32+.WAWebProtobufsBotMetadata.BotMediaMetadata\"e\n\x18\x42otAgeCollectionMetadata\x12\x1d\n\x15\x61geCollectionEligible\x18\x01 \x01(\x08\x12*\n\"shouldTriggerAgeCollectionOnClient\x18\x02 \x01(\x08\"X\n\x18\x42otMessageOriginMetadata\x12<\n\x07origins\x18\x01 \x03(\x0b\x32+.WAWebProtobufsBotMetadata.BotMessageOrigin\"\xac\x01\n\x1a\x42otUnifiedResponseMutation\x12]\n\x0bsbsMetadata\x18\x01 \x01(\x0b\x32H.WAWebProtobufsBotMetadata.BotUnifiedResponseMutation.SideBySideMetadata\x1a/\n\x12SideBySideMetadata\x12\x19\n\x11primaryResponseID\x18\x01 \x01(\t\"\x94\x0f\n\x0b\x42otMetadata\x12\x44\n\x0e\x61vatarMetadata\x18\x01 \x01(\x0b\x32,.WAWebProtobufsBotMetadata.BotAvatarMetadata\x12\x11\n\tpersonaID\x18\x02 \x01(\t\x12\x44\n\x0epluginMetadata\x18\x03 \x01(\x0b\x32,.WAWebProtobufsBotMetadata.BotPluginMetadata\x12V\n\x17suggestedPromptMetadata\x18\x04 \x01(\x0b\x32\x35.WAWebProtobufsBotMetadata.BotSuggestedPromptMetadata\x12\x12\n\ninvokerJID\x18\x05 \x01(\t\x12\x46\n\x0fsessionMetadata\x18\x06 \x01(\x0b\x32-.WAWebProtobufsBotMetadata.BotSessionMetadata\x12@\n\x0cmemuMetadata\x18\x07 \x01(\x0b\x32*.WAWebProtobufsBotMetadata.BotMemuMetadata\x12\x10\n\x08timezone\x18\x08 \x01(\t\x12H\n\x10reminderMetadata\x18\t \x01(\x0b\x32..WAWebProtobufsBotMetadata.BotReminderMetadata\x12\x42\n\rmodelMetadata\x18\n \x01(\x0b\x32+.WAWebProtobufsBotMetadata.BotModelMetadata\x12\x1d\n\x15messageDisclaimerText\x18\x0b \x01(\t\x12Z\n\x19progressIndicatorMetadata\x18\x0c \x01(\x0b\x32\x37.WAWebProtobufsBotMetadata.BotProgressIndicatorMetadata\x12L\n\x12\x63\x61pabilityMetadata\x18\r \x01(\x0b\x32\x30.WAWebProtobufsBotMetadata.BotCapabilityMetadata\x12\x46\n\x0fimagineMetadata\x18\x0e \x01(\x0b\x32-.WAWebProtobufsBotMetadata.BotImagineMetadata\x12\x44\n\x0ememoryMetadata\x18\x0f \x01(\x0b\x32,.WAWebProtobufsBotMetadata.BotMemoryMetadata\x12J\n\x11renderingMetadata\x18\x10 \x01(\x0b\x32/.WAWebProtobufsBotMetadata.BotRenderingMetadata\x12I\n\x12\x62otMetricsMetadata\x18\x11 \x01(\x0b\x32-.WAWebProtobufsBotMetadata.BotMetricsMetadata\x12W\n\x19\x62otLinkedAccountsMetadata\x18\x12 \x01(\x0b\x32\x34.WAWebProtobufsBotMetadata.BotLinkedAccountsMetadata\x12R\n\x1brichResponseSourcesMetadata\x18\x13 \x01(\x0b\x32-.WAWebProtobufsBotMetadata.BotSourcesMetadata\x12\x1d\n\x15\x61iConversationContext\x18\x14 \x01(\x0c\x12[\n\x1b\x62otPromotionMessageMetadata\x18\x15 \x01(\x0b\x32\x36.WAWebProtobufsBotMetadata.BotPromotionMessageMetadata\x12U\n\x18\x62otModeSelectionMetadata\x18\x16 \x01(\x0b\x32\x33.WAWebProtobufsBotMetadata.BotModeSelectionMetadata\x12\x45\n\x10\x62otQuotaMetadata\x18\x17 \x01(\x0b\x32+.WAWebProtobufsBotMetadata.BotQuotaMetadata\x12U\n\x18\x62otAgeCollectionMetadata\x18\x18 \x01(\x0b\x32\x33.WAWebProtobufsBotMetadata.BotAgeCollectionMetadata\x12#\n\x1b\x63onversationStarterPromptID\x18\x19 \x01(\t\x12\x15\n\rbotResponseID\x18\x1a \x01(\t\x12Y\n\x14verificationMetadata\x18\x1b \x01(\x0b\x32;.WAWebProtobufsBotMetadata.BotSignatureVerificationMetadata\x12V\n\x17unifiedResponseMutation\x18\x1c \x01(\x0b\x32\x35.WAWebProtobufsBotMetadata.BotUnifiedResponseMutation\x12U\n\x18\x62otMessageOriginMetadata\x18\x1d \x01(\x0b\x32\x33.WAWebProtobufsBotMetadata.BotMessageOriginMetadata*\xac\x06\n\x14\x42otMetricsEntryPoint\x12\x0b\n\x07\x46\x41VICON\x10\x01\x12\x0c\n\x08\x43HATLIST\x10\x02\x12#\n\x1f\x41ISEARCH_NULL_STATE_PAPER_PLANE\x10\x03\x12\"\n\x1e\x41ISEARCH_NULL_STATE_SUGGESTION\x10\x04\x12\"\n\x1e\x41ISEARCH_TYPE_AHEAD_SUGGESTION\x10\x05\x12#\n\x1f\x41ISEARCH_TYPE_AHEAD_PAPER_PLANE\x10\x06\x12\'\n#AISEARCH_TYPE_AHEAD_RESULT_CHATLIST\x10\x07\x12\'\n#AISEARCH_TYPE_AHEAD_RESULT_MESSAGES\x10\x08\x12\x16\n\x12\x41IVOICE_SEARCH_BAR\x10\t\x12\x13\n\x0f\x41IVOICE_FAVICON\x10\n\x12\x0c\n\x08\x41ISTUDIO\x10\x0b\x12\x0c\n\x08\x44\x45\x45PLINK\x10\x0c\x12\x10\n\x0cNOTIFICATION\x10\r\x12\x1a\n\x16PROFILE_MESSAGE_BUTTON\x10\x0e\x12\x0b\n\x07\x46ORWARD\x10\x0f\x12\x10\n\x0c\x41PP_SHORTCUT\x10\x10\x12\r\n\tFF_FAMILY\x10\x11\x12\n\n\x06\x41I_TAB\x10\x12\x12\x0b\n\x07\x41I_HOME\x10\x13\x12\x19\n\x15\x41I_DEEPLINK_IMMERSIVE\x10\x14\x12\x0f\n\x0b\x41I_DEEPLINK\x10\x15\x12#\n\x1fMETA_AI_CHAT_SHORTCUT_AI_STUDIO\x10\x16\x12\x1f\n\x1bUGC_CHAT_SHORTCUT_AI_STUDIO\x10\x17\x12\x16\n\x12NEW_CHAT_AI_STUDIO\x10\x18\x12 \n\x1c\x41IVOICE_FAVICON_CALL_HISTORY\x10\x19\x12\x1c\n\x18\x41SK_META_AI_CONTEXT_MENU\x10\x1a\x12!\n\x1d\x41SK_META_AI_CONTEXT_MENU_1ON1\x10\x1b\x12\"\n\x1e\x41SK_META_AI_CONTEXT_MENU_GROUP\x10\x1c\x12\x17\n\x13INVOKE_META_AI_1ON1\x10\x1d\x12\x18\n\x14INVOKE_META_AI_GROUP\x10\x1e\x12\x13\n\x0fMETA_AI_FORWARD\x10\x1f*\xa2\x01\n\x1a\x42otMetricsThreadEntryPoint\x12\x11\n\rAI_TAB_THREAD\x10\x01\x12\x12\n\x0e\x41I_HOME_THREAD\x10\x02\x12 \n\x1c\x41I_DEEPLINK_IMMERSIVE_THREAD\x10\x03\x12\x16\n\x12\x41I_DEEPLINK_THREAD\x10\x04\x12#\n\x1f\x41SK_META_AI_CONTEXT_MENU_THREAD\x10\x05*}\n\x10\x42otSessionSource\x12\x08\n\x04NONE\x10\x00\x12\x0e\n\nNULL_STATE\x10\x01\x12\r\n\tTYPEAHEAD\x10\x02\x12\x0e\n\nUSER_INPUT\x10\x03\x12\r\n\tEMU_FLASH\x10\x04\x12\x16\n\x12\x45MU_FLASH_FOLLOWUP\x10\x05\x12\t\n\x05VOICE\x10\x06\x42)Z\'go.mau.fi/whatsmeow/proto/waBotMetadata')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waBotMetadata.WAWebProtobufsBotMetadata_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\'go.mau.fi/whatsmeow/proto/waBotMetadata'
  _globals['_BOTMETRICSENTRYPOINT']._serialized_start=10465
  _globals['_BOTMETRICSENTRYPOINT']._serialized_end=11277
  _globals['_BOTMETRICSTHREADENTRYPOINT']._serialized_start=11280
  _globals['_BOTMETRICSTHREADENTRYPOINT']._serialized_end=11442
  _globals['_BOTSESSIONSOURCE']._serialized_start=11444
  _globals['_BOTSESSIONSOURCE']._serialized_end=11569
  _globals['_BOTPLUGINMETADATA']._serialized_start=102
  _globals['_BOTPLUGINMETADATA']._serialized_end=795
  _globals['_BOTPLUGINMETADATA_PLUGINTYPE']._serialized_start=674
  _globals['_BOTPLUGINMETADATA_PLUGINTYPE']._serialized_end=729
  _globals['_BOTPLUGINMETADATA_SEARCHPROVIDER']._serialized_start=731
  _globals['_BOTPLUGINMETADATA_SEARCHPROVIDER']._serialized_end=795
  _globals['_BOTLINKEDACCOUNT']._serialized_start=798
  _globals['_BOTLINKEDACCOUNT']._serialized_end=952
  _globals['_BOTLINKEDACCOUNT_BOTLINKEDACCOUNTTYPE']._serialized_start=898
  _globals['_BOTLINKEDACCOUNT_BOTLINKEDACCOUNTTYPE']._serialized_end=952
  _globals['_BOTSIGNATUREVERIFICATIONUSECASEPROOF']._serialized_start=955
  _globals['_BOTSIGNATUREVERIFICATIONUSECASEPROOF']._serialized_end=1196
  _globals['_BOTSIGNATUREVERIFICATIONUSECASEPROOF_BOTSIGNATUREUSECASE']._serialized_start=1159
  _globals['_BOTSIGNATUREVERIFICATIONUSECASEPROOF_BOTSIGNATUREUSECASE']._serialized_end=1196
  _globals['_BOTPROMOTIONMESSAGEMETADATA']._serialized_start=1199
  _globals['_BOTPROMOTIONMESSAGEMETADATA']._serialized_end=1392
  _globals['_BOTPROMOTIONMESSAGEMETADATA_BOTPROMOTIONTYPE']._serialized_start=1347
  _globals['_BOTPROMOTIONMESSAGEMETADATA_BOTPROMOTIONTYPE']._serialized_end=1392
  _globals['_BOTMEDIAMETADATA']._serialized_start=1395
  _globals['_BOTMEDIAMETADATA']._serialized_end=1677
  _globals['_BOTMEDIAMETADATA_ORIENTATIONTYPE']._serialized_start=1627
  _globals['_BOTMEDIAMETADATA_ORIENTATIONTYPE']._serialized_end=1677
  _globals['_BOTREMINDERMETADATA']._serialized_start=1680
  _globals['_BOTREMINDERMETADATA']._serialized_end=2105
  _globals['_BOTREMINDERMETADATA_REMINDERFREQUENCY']._serialized_start=1960
  _globals['_BOTREMINDERMETADATA_REMINDERFREQUENCY']._serialized_end=2039
  _globals['_BOTREMINDERMETADATA_REMINDERACTION']._serialized_start=2041
  _globals['_BOTREMINDERMETADATA_REMINDERACTION']._serialized_end=2105
  _globals['_BOTMODELMETADATA']._serialized_start=2108
  _globals['_BOTMODELMETADATA']._serialized_end=2444
  _globals['_BOTMODELMETADATA_PREMIUMMODELSTATUS']._serialized_start=2294
  _globals['_BOTMODELMETADATA_PREMIUMMODELSTATUS']._serialized_end=2373
  _globals['_BOTMODELMETADATA_MODELTYPE']._serialized_start=2375
  _globals['_BOTMODELMETADATA_MODELTYPE']._serialized_end=2444
  _globals['_BOTPROGRESSINDICATORMETADATA']._serialized_start=2447
  _globals['_BOTPROGRESSINDICATORMETADATA']._serialized_end=4026
  _globals['_BOTPROGRESSINDICATORMETADATA_BOTPLANNINGSTEPMETADATA']._serialized_start=2613
  _globals['_BOTPROGRESSINDICATORMETADATA_BOTPLANNINGSTEPMETADATA']._serialized_end=4026
  _globals['_BOTPROGRESSINDICATORMETADATA_BOTPLANNINGSTEPMETADATA_BOTPLANNINGSEARCHSOURCESMETADATA']._serialized_start=3116
  _globals['_BOTPROGRESSINDICATORMETADATA_BOTPLANNINGSTEPMETADATA_BOTPLANNINGSEARCHSOURCESMETADATA']._serialized_end=3437
  _globals['_BOTPROGRESSINDICATORMETADATA_BOTPLANNINGSTEPMETADATA_BOTPLANNINGSEARCHSOURCESMETADATA_BOTPLANNINGSEARCHSOURCEPROVIDER']._serialized_start=3358
  _globals['_BOTPROGRESSINDICATORMETADATA_BOTPLANNINGSTEPMETADATA_BOTPLANNINGSEARCHSOURCESMETADATA_BOTPLANNINGSEARCHSOURCEPROVIDER']._serialized_end=3437
  _globals['_BOTPROGRESSINDICATORMETADATA_BOTPLANNINGSTEPMETADATA_BOTPLANNINGSTEPSECTIONMETADATA']._serialized_start=3440
  _globals['_BOTPROGRESSINDICATORMETADATA_BOTPLANNINGSTEPMETADATA_BOTPLANNINGSTEPSECTIONMETADATA']._serialized_end=3654
  _globals['_BOTPROGRESSINDICATORMETADATA_BOTPLANNINGSTEPMETADATA_BOTPLANNINGSEARCHSOURCEMETADATA']._serialized_start=3657
  _globals['_BOTPROGRESSINDICATORMETADATA_BOTPLANNINGSTEPMETADATA_BOTPLANNINGSEARCHSOURCEMETADATA']._serialized_end=3867
  _globals['_BOTPROGRESSINDICATORMETADATA_BOTPLANNINGSTEPMETADATA_BOTSEARCHSOURCEPROVIDER']._serialized_start=3869
  _globals['_BOTPROGRESSINDICATORMETADATA_BOTPLANNINGSTEPMETADATA_BOTSEARCHSOURCEPROVIDER']._serialized_end=3949
  _globals['_BOTPROGRESSINDICATORMETADATA_BOTPLANNINGSTEPMETADATA_PLANNINGSTEPSTATUS']._serialized_start=3951
  _globals['_BOTPROGRESSINDICATORMETADATA_BOTPLANNINGSTEPMETADATA_PLANNINGSTEPSTATUS']._serialized_end=4026
  _globals['_BOTCAPABILITYMETADATA']._serialized_start=4029
  _globals['_BOTCAPABILITYMETADATA']._serialized_end=5356
  _globals['_BOTCAPABILITYMETADATA_BOTCAPABILITYTYPE']._serialized_start=4145
  _globals['_BOTCAPABILITYMETADATA_BOTCAPABILITYTYPE']._serialized_end=5356
  _globals['_BOTMODESELECTIONMETADATA']._serialized_start=5359
  _globals['_BOTMODESELECTIONMETADATA']._serialized_end=5535
  _globals['_BOTMODESELECTIONMETADATA_BOTUSERSELECTIONMODE']._serialized_start=5475
  _globals['_BOTMODESELECTIONMETADATA_BOTUSERSELECTIONMODE']._serialized_end=5535
  _globals['_BOTQUOTAMETADATA']._serialized_start=5538
  _globals['_BOTQUOTAMETADATA']._serialized_end=5906
  _globals['_BOTQUOTAMETADATA_BOTFEATUREQUOTAMETADATA']._serialized_start=5661
  _globals['_BOTQUOTAMETADATA_BOTFEATUREQUOTAMETADATA']._serialized_end=5906
  _globals['_BOTQUOTAMETADATA_BOTFEATUREQUOTAMETADATA_BOTFEATURETYPE']._serialized_start=5846
  _globals['_BOTQUOTAMETADATA_BOTFEATUREQUOTAMETADATA_BOTFEATURETYPE']._serialized_end=5906
  _globals['_BOTIMAGINEMETADATA']._serialized_start=5909
  _globals['_BOTIMAGINEMETADATA']._serialized_end=6081
  _globals['_BOTIMAGINEMETADATA_IMAGINETYPE']._serialized_start=6011
  _globals['_BOTIMAGINEMETADATA_IMAGINETYPE']._serialized_end=6081
  _globals['_BOTSOURCESMETADATA']._serialized_start=6084
  _globals['_BOTSOURCESMETADATA']._serialized_end=6512
  _globals['_BOTSOURCESMETADATA_BOTSOURCEITEM']._serialized_start=6185
  _globals['_BOTSOURCESMETADATA_BOTSOURCEITEM']._serialized_end=6512
  _globals['_BOTSOURCESMETADATA_BOTSOURCEITEM_SOURCEPROVIDER']._serialized_start=6437
  _globals['_BOTSOURCESMETADATA_BOTSOURCEITEM_SOURCEPROVIDER']._serialized_end=6512
  _globals['_BOTMESSAGEORIGIN']._serialized_start=6515
  _globals['_BOTMESSAGEORIGIN']._serialized_end=6679
  _globals['_BOTMESSAGEORIGIN_BOTMESSAGEORIGINTYPE']._serialized_start=6615
  _globals['_BOTMESSAGEORIGIN_BOTMESSAGEORIGINTYPE']._serialized_end=6679
  _globals['_BOTAVATARMETADATA']._serialized_start=6681
  _globals['_BOTAVATARMETADATA']._serialized_end=6796
  _globals['_BOTSUGGESTEDPROMPTMETADATA']._serialized_start=6799
  _globals['_BOTSUGGESTEDPROMPTMETADATA']._serialized_end=6984
  _globals['_BOTPROMPTSUGGESTIONS']._serialized_start=6986
  _globals['_BOTPROMPTSUGGESTIONS']._serialized_end=7077
  _globals['_BOTPROMPTSUGGESTION']._serialized_start=7079
  _globals['_BOTPROMPTSUGGESTION']._serialized_end=7134
  _globals['_BOTLINKEDACCOUNTSMETADATA']._serialized_start=7137
  _globals['_BOTLINKEDACCOUNTSMETADATA']._serialized_end=7270
  _globals['_BOTMEMORYMETADATA']._serialized_start=7273
  _globals['_BOTMEMORYMETADATA']._serialized_end=7438
  _globals['_BOTMEMORYFACT']._serialized_start=7440
  _globals['_BOTMEMORYFACT']._serialized_end=7485
  _globals['_BOTSIGNATUREVERIFICATIONMETADATA']._serialized_start=7487
  _globals['_BOTSIGNATUREVERIFICATIONMETADATA']._serialized_end=7602
  _globals['_BOTRENDERINGMETADATA']._serialized_start=7605
  _globals['_BOTRENDERINGMETADATA']._serialized_end=7755
  _globals['_BOTRENDERINGMETADATA_KEYWORD']._serialized_start=7704
  _globals['_BOTRENDERINGMETADATA_KEYWORD']._serialized_end=7755
  _globals['_BOTMETRICSMETADATA']._serialized_start=7758
  _globals['_BOTMETRICSMETADATA']._serialized_end=7958
  _globals['_BOTSESSIONMETADATA']._serialized_start=7960
  _globals['_BOTSESSIONMETADATA']._serialized_end=8067
  _globals['_BOTMEMUMETADATA']._serialized_start=8069
  _globals['_BOTMEMUMETADATA']._serialized_end=8151
  _globals['_BOTAGECOLLECTIONMETADATA']._serialized_start=8153
  _globals['_BOTAGECOLLECTIONMETADATA']._serialized_end=8254
  _globals['_BOTMESSAGEORIGINMETADATA']._serialized_start=8256
  _globals['_BOTMESSAGEORIGINMETADATA']._serialized_end=8344
  _globals['_BOTUNIFIEDRESPONSEMUTATION']._serialized_start=8347
  _globals['_BOTUNIFIEDRESPONSEMUTATION']._serialized_end=8519
  _globals['_BOTUNIFIEDRESPONSEMUTATION_SIDEBYSIDEMETADATA']._serialized_start=8472
  _globals['_BOTUNIFIEDRESPONSEMUTATION_SIDEBYSIDEMETADATA']._serialized_end=8519
  _globals['_BOTMETADATA']._serialized_start=8522
  _globals['_BOTMETADATA']._serialized_end=10462
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waSyncdSnapshotRecovery/WAWebProtobufsSyncdSnapshotRecovery.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'waSyncdSnapshotRecovery/WAWebProtobufsSyncdSnapshotRecovery.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from waSyncAction import WASyncAction_pb2 as waSyncAction_dot_WASyncAction__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAwaSyncdSnapshotRecovery/WAWebProtobufsSyncdSnapshotRecovery.proto\x12#WAWebProtobufsSyncdSnapshotRecovery\x1a\x1fwaSyncAction/WASyncAction.proto\"\xe1\x01\n\x15SyncdSnapshotRecovery\x12\x42\n\x07version\x18\x01 \x01(\x0b\x32\x31.WAWebProtobufsSyncdSnapshotRecovery.SyncdVersion\x12\x16\n\x0e\x63ollectionName\x18\x02 \x01(\t\x12R\n\x0fmutationRecords\x18\x03 \x03(\x0b\x32\x39.WAWebProtobufsSyncdSnapshotRecovery.SyncdPlainTextRecord\x12\x18\n\x10\x63ollectionLthash\x18\x04 \x01(\x0c\"_\n\x14SyncdPlainTextRecord\x12+\n\x05value\x18\x01 \x01(\x0b\x32\x1c.WASyncAction.SyncActionData\x12\r\n\x05keyID\x18\x02 \x01(\x0c\x12\x0b\n\x03mac\x18\x03 \x01(\x0c\"\x1f\n\x0cSyncdVersion\x12\x0f\n\x07version\x18\x01 \x01(\x04\x42\x33Z1go.mau.fi/whatsmeow/proto/waSyncdSnapshotRecovery')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waSyncdSnapshotRecovery.WAWebProtobufsSyncdSnapshotRecovery_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1go.mau.fi/whatsmeow/proto/waSyncdSnapshotRecovery'
  _globals['_SYNCDSNAPSHOTRECOVERY']._serialized_start=140
  _globals['_SYNCDSNAPSHOTRECOVERY']._serialized_end=365
  _globals['_SYNCDPLAINTEXTRECORD']._serialized_start=367
  _globals['_SYNCDPLAINTEXTRECORD']._serialized_end=462
  _globals['_SYNCDVERSION']._serialized_start=464
  _globals['_SYNCDVERSION']._serialized_end=495
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Message(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class ExtendedTextMessage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TEXT_FIELD_NUMBER: builtins.int
        CONTEXTINFO_FIELD_NUMBER: builtins.int
        text: builtins.str
        @property
        def contextInfo(self) -> global___Message.ContextInfo: ...
        def __init__(
            self,
            *,
            text: builtins.str | None = ...,
            contextInfo: global___Message.ContextInfo | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["contextInfo", b"contextInfo", "text", b"text"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["contextInfo", b"contextInfo", "text", b"text"]) -> None: ...

    @typing.final
    class ContextInfo(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        STANZAID_FIELD_NUMBER: builtins.int
        PARTICIPANT_FIELD_NUMBER: builtins.int
        QUOTEDMESSAGE_FIELD_NUMBER: builtins.int
        stanzaID: builtins.str
        participant: builtins.str
        @property
        def quotedMessage(self) -> global___Message: ...
        def __init__(
            self,
            *,
            stanzaID: builtins.str | None = ...,
            participant: builtins.str | None = ...,
            quotedMessage: global___Message | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["participant", b"participant", "quotedMessage", b"quotedMessage", "stanzaID", b"stanzaID"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["participant", b"participant", "quotedMessage", b"quotedMessage", "stanzaID", b"stanzaID"]) -> None: ...

    CONVERSATION_FIELD_NUMBER: builtins.int
    EXTENDEDTEXTMESSAGE_FIELD_NUMBER: builtins.int
    MESSAGECONTEXTINFO_FIELD_NUMBER: builtins.int
    conversation: builtins.str
    @property
    def extendedTextMessage(self) -> global___Message.ExtendedTextMessage: ...
    @property
    def messageContextInfo(self) -> global___MessageContextInfo: ...
    def __init__(
        self,
        *,
        conversation: builtins.str | None = ...,
        extendedTextMessage: global___Message.ExtendedTextMessage | None = ...,
        messageContextInfo: global___MessageContextInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["conversation", b"conversation", "extendedTextMessage", b"extendedTextMessage", "messageContextInfo", b"messageContextInfo"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["conversation", b"conversation", "extendedTextMessage", b"extendedTextMessage", "messageContextInfo", b"messageContextInfo"]) -> None: ...

global___Message = Message

@typing.final
class MessageContextInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGESECRET_FIELD_NUMBER: builtins.int
    messageSecret: builtins.bytes
    def __init__(
        self,
        *,
        messageSecret: builtins.bytes | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["messageSecret", b"messageSecret"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["messageSecret", b"messageSecret"]) -> None: ...

global___MessageContextInfo = MessageContextInfo



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import instamadilloAddMessage.InstamadilloAddMessage_pb2
import instamadilloDeleteMessage.InstamadilloDeleteMessage_pb2
import instamadilloSupplementMessage.InstamadilloSupplementMessage_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _PayloadCreator:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PayloadCreatorEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PayloadCreator.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PAYLOAD_CREATOR_UNSPECIFIED: _PayloadCreator.ValueType  # 0
    PAYLOAD_CREATOR_IGIOS: _PayloadCreator.ValueType  # 1
    PAYLOAD_CREATOR_IG4A: _PayloadCreator.ValueType  # 2
    PAYLOAD_CREATOR_WWW: _PayloadCreator.ValueType  # 3
    PAYLOAD_CREATOR_IGLITE: _PayloadCreator.ValueType  # 4

class PayloadCreator(_PayloadCreator, metaclass=_PayloadCreatorEnumTypeWrapper): ...

PAYLOAD_CREATOR_UNSPECIFIED: PayloadCreator.ValueType  # 0
PAYLOAD_CREATOR_IGIOS: PayloadCreator.ValueType  # 1
PAYLOAD_CREATOR_IG4A: PayloadCreator.ValueType  # 2
PAYLOAD_CREATOR_WWW: PayloadCreator.ValueType  # 3
PAYLOAD_CREATOR_IGLITE: PayloadCreator.ValueType  # 4
global___PayloadCreator = PayloadCreator

@typing.final
class TransportPayload(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADD_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    SUPPLEMENT_FIELD_NUMBER: builtins.int
    FRANKING_FIELD_NUMBER: builtins.int
    OPENEB_FIELD_NUMBER: builtins.int
    ISE2EEATTRIBUTED_FIELD_NUMBER: builtins.int
    PAYLOADCREATOR_FIELD_NUMBER: builtins.int
    openEb: builtins.bool
    isE2EeAttributed: builtins.bool
    payloadCreator: global___PayloadCreator.ValueType
    @property
    def add(self) -> instamadilloAddMessage.InstamadilloAddMessage_pb2.AddMessagePayload: ...
    @property
    def delete(self) -> instamadilloDeleteMessage.InstamadilloDeleteMessage_pb2.DeleteMessagePayload: ...
    @property
    def supplement(self) -> instamadilloSupplementMessage.InstamadilloSupplementMessage_pb2.SupplementMessagePayload: ...
    @property
    def franking(self) -> global___Franking: ...
    def __init__(
        self,
        *,
        add: instamadilloAddMessage.InstamadilloAddMessage_pb2.AddMessagePayload | None = ...,
        delete: instamadilloDeleteMessage.InstamadilloDeleteMessage_pb2.DeleteMessagePayload | None = ...,
        supplement: instamadilloSupplementMessage.InstamadilloSupplementMessage_pb2.SupplementMessagePayload | None = ...,
        franking: global___Franking | None = ...,
        openEb: builtins.bool | None = ...,
        isE2EeAttributed: builtins.bool | None = ...,
        payloadCreator: global___PayloadCreator.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["add", b"add", "delete", b"delete", "franking", b"franking", "isE2EeAttributed", b"isE2EeAttributed", "openEb", b"openEb", "payloadCreator", b"payloadCreator", "supplement", b"supplement", "transportPayload", b"transportPayload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["add", b"add", "delete", b"delete", "franking", b"franking", "isE2EeAttributed", b"isE2EeAttributed", "openEb", b"openEb", "payloadCreator", b"payloadCreator", "supplement", b"supplement", "transportPayload", b"transportPayload"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["transportPayload", b"transportPayload"]) -> typing.Literal["add", "delete", "supplement"] | None: ...

global___TransportPayload = TransportPayload

@typing.final
class Franking(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FRANKINGKEY_FIELD_NUMBER: builtins.int
    FRANKINGVERSION_FIELD_NUMBER: builtins.int
    frankingKey: builtins.bytes
    frankingVersion: builtins.int
    def __init__(
        self,
        *,
        frankingKey: builtins.bytes | None = ...,
        frankingVersion: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["frankingKey", b"frankingKey", "frankingVersion", b"frankingVersion"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["frankingKey", b"frankingKey", "frankingVersion", b"frankingVersion"]) -> None: ...

global___Franking = Franking



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: instamadilloTransportPayload/InstamadilloTransportPayload.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'instamadilloTransportPayload/InstamadilloTransportPayload.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from instamadilloAddMessage import InstamadilloAddMessage_pb2 as instamadilloAddMessage_dot_InstamadilloAddMessage__pb2
from instamadilloDeleteMessage import InstamadilloDeleteMessage_pb2 as instamadilloDeleteMessage_dot_InstamadilloDeleteMessage__pb2
from instamadilloSupplementMessage import InstamadilloSupplementMessage_pb2 as instamadilloSupplementMessage_dot_InstamadilloSupplementMessage__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?instamadilloTransportPayload/InstamadilloTransportPayload.proto\x12\x1cInstamadilloTransportPayload\x1a\x33instamadilloAddMessage/InstamadilloAddMessage.proto\x1a\x39instamadilloDeleteMessage/InstamadilloDeleteMessage.proto\x1a\x41instamadilloSupplementMessage/InstamadilloSupplementMessage.proto\"\x9c\x03\n\x10TransportPayload\x12\x38\n\x03\x61\x64\x64\x18\x01 \x01(\x0b\x32).InstamadilloAddMessage.AddMessagePayloadH\x00\x12\x41\n\x06\x64\x65lete\x18\x02 \x01(\x0b\x32/.InstamadilloDeleteMessage.DeleteMessagePayloadH\x00\x12M\n\nsupplement\x18\x03 \x01(\x0b\x32\x37.InstamadilloSupplementMessage.SupplementMessagePayloadH\x00\x12\x38\n\x08\x66ranking\x18\x04 \x01(\x0b\x32&.InstamadilloTransportPayload.Franking\x12\x0e\n\x06openEb\x18\x05 \x01(\x08\x12\x18\n\x10isE2EeAttributed\x18\x06 \x01(\x08\x12\x44\n\x0epayloadCreator\x18\x07 \x01(\x0e\x32,.InstamadilloTransportPayload.PayloadCreatorB\x12\n\x10transportPayload\"8\n\x08\x46ranking\x12\x13\n\x0b\x66rankingKey\x18\x01 \x01(\x0c\x12\x17\n\x0f\x66rankingVersion\x18\x02 \x01(\x05*\x9b\x01\n\x0ePayloadCreator\x12\x1f\n\x1bPAYLOAD_CREATOR_UNSPECIFIED\x10\x00\x12\x19\n\x15PAYLOAD_CREATOR_IGIOS\x10\x01\x12\x18\n\x14PAYLOAD_CREATOR_IG4A\x10\x02\x12\x17\n\x13PAYLOAD_CREATOR_WWW\x10\x03\x12\x1a\n\x16PAYLOAD_CREATOR_IGLITE\x10\x04\x42\x38Z6go.mau.fi/whatsmeow/proto/instamadilloTransportPayload')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'instamadilloTransportPayload.InstamadilloTransportPayload_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z6go.mau.fi/whatsmeow/proto/instamadilloTransportPayload'
  _globals['_PAYLOADCREATOR']._serialized_start=750
  _globals['_PAYLOADCREATOR']._serialized_end=905
  _globals['_TRANSPORTPAYLOAD']._serialized_start=277
  _globals['_TRANSPORTPAYLOAD']._serialized_end=689
  _globals['_FRANKING']._serialized_start=691
  _globals['_FRANKING']._serialized_end=747
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waCommonParameterised/WACommonParameterised.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'waCommonParameterised/WACommonParameterised.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1waCommonParameterised/WACommonParameterised.proto\x12\x15WACommonParameterised\"P\n\nMessageKey\x12\x11\n\tremoteJID\x18\x01 \x01(\t\x12\x0e\n\x06\x66romMe\x18\x02 \x01(\x08\x12\n\n\x02ID\x18\x03 \x01(\t\x12\x13\n\x0bparticipant\x18\x04 \x01(\t\"\xc4\x01\n\x07\x43ommand\x12?\n\x0b\x63ommandType\x18\x01 \x01(\x0e\x32*.WACommonParameterised.Command.CommandType\x12\x0e\n\x06offset\x18\x02 \x01(\r\x12\x0e\n\x06length\x18\x03 \x01(\r\x12\x17\n\x0fvalidationToken\x18\x04 \x01(\t\"?\n\x0b\x43ommandType\x12\x0c\n\x08\x45VERYONE\x10\x01\x12\n\n\x06SILENT\x10\x02\x12\x06\n\x02\x41I\x10\x03\x12\x0e\n\nAI_IMAGINE\x10\x04\"\x9c\x01\n\x07Mention\x12?\n\x0bmentionType\x18\x01 \x01(\x0e\x32*.WACommonParameterised.Mention.MentionType\x12\x14\n\x0cmentionedJID\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\x03 \x01(\r\x12\x0e\n\x06length\x18\x04 \x01(\r\"\x1a\n\x0bMentionType\x12\x0b\n\x07PROFILE\x10\x00\"\x95\x01\n\x0bMessageText\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x14\n\x0cmentionedJID\x18\x02 \x03(\t\x12\x30\n\x08\x63ommands\x18\x03 \x03(\x0b\x32\x1e.WACommonParameterised.Command\x12\x30\n\x08mentions\x18\x04 \x03(\x0b\x32\x1e.WACommonParameterised.Mention\"/\n\x0bSubProtocol\x12\x0f\n\x07payload\x18\x01 \x01(\x0c\x12\x0f\n\x07version\x18\x02 \x01(\x05*F\n\x13\x46utureProofBehavior\x12\x0f\n\x0bPLACEHOLDER\x10\x00\x12\x12\n\x0eNO_PLACEHOLDER\x10\x01\x12\n\n\x06IGNORE\x10\x02\x42\x31Z/go.mau.fi/whatsmeow/proto/waCommonParameterised')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waCommonParameterised.WACommonParameterised_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z/go.mau.fi/whatsmeow/proto/waCommonParameterised'
  _globals['_FUTUREPROOFBEHAVIOR']._serialized_start=717
  _globals['_FUTUREPROOFBEHAVIOR']._serialized_end=787
  _globals['_MESSAGEKEY']._serialized_start=76
  _globals['_MESSAGEKEY']._serialized_end=156
  _globals['_COMMAND']._serialized_start=159
  _globals['_COMMAND']._serialized_end=355
  _globals['_COMMAND_COMMANDTYPE']._serialized_start=292
  _globals['_COMMAND_COMMANDTYPE']._serialized_end=355
  _globals['_MENTION']._serialized_start=358
  _globals['_MENTION']._serialized_end=514
  _globals['_MENTION_MENTIONTYPE']._serialized_start=488
  _globals['_MENTION_MENTIONTYPE']._serialized_end=514
  _globals['_MESSAGETEXT']._serialized_start=517
  _globals['_MESSAGETEXT']._serialized_end=666
  _globals['_SUBPROTOCOL']._serialized_start=668
  _globals['_SUBPROTOCOL']._serialized_end=715
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class MiTransportAdminMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LimitSharingChanged(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _SharingType:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _SharingTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MiTransportAdminMessage.LimitSharingChanged._SharingType.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            UNSET: MiTransportAdminMessage.LimitSharingChanged._SharingType.ValueType  # 0
            DISABLED: MiTransportAdminMessage.LimitSharingChanged._SharingType.ValueType  # 1
            ENABLED: MiTransportAdminMessage.LimitSharingChanged._SharingType.ValueType  # 2

        class SharingType(_SharingType, metaclass=_SharingTypeEnumTypeWrapper): ...
        UNSET: MiTransportAdminMessage.LimitSharingChanged.SharingType.ValueType  # 0
        DISABLED: MiTransportAdminMessage.LimitSharingChanged.SharingType.ValueType  # 1
        ENABLED: MiTransportAdminMessage.LimitSharingChanged.SharingType.ValueType  # 2

        SHARINGTYPE_FIELD_NUMBER: builtins.int
        sharingType: global___MiTransportAdminMessage.LimitSharingChanged.SharingType.ValueType
        def __init__(
            self,
            *,
            sharingType: global___MiTransportAdminMessage.LimitSharingChanged.SharingType.ValueType | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["sharingType", b"sharingType"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["sharingType", b"sharingType"]) -> None: ...

    @typing.final
    class GroupImageChanged(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _Action:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _ActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MiTransportAdminMessage.GroupImageChanged._Action.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            UNSET: MiTransportAdminMessage.GroupImageChanged._Action.ValueType  # 0
            CHANGED: MiTransportAdminMessage.GroupImageChanged._Action.ValueType  # 1
            REMOVED: MiTransportAdminMessage.GroupImageChanged._Action.ValueType  # 2

        class Action(_Action, metaclass=_ActionEnumTypeWrapper): ...
        UNSET: MiTransportAdminMessage.GroupImageChanged.Action.ValueType  # 0
        CHANGED: MiTransportAdminMessage.GroupImageChanged.Action.ValueType  # 1
        REMOVED: MiTransportAdminMessage.GroupImageChanged.Action.ValueType  # 2

        ACTION_FIELD_NUMBER: builtins.int
        action: global___MiTransportAdminMessage.GroupImageChanged.Action.ValueType
        def __init__(
            self,
            *,
            action: global___MiTransportAdminMessage.GroupImageChanged.Action.ValueType | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["action", b"action"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["action", b"action"]) -> None: ...

    @typing.final
    class MessagePinned(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _Action:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _ActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MiTransportAdminMessage.MessagePinned._Action.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            UNSET: MiTransportAdminMessage.MessagePinned._Action.ValueType  # 0
            PINNED: MiTransportAdminMessage.MessagePinned._Action.ValueType  # 1
            UNPINNED: MiTransportAdminMessage.MessagePinned._Action.ValueType  # 2

        class Action(_Action, metaclass=_ActionEnumTypeWrapper): ...
        UNSET: MiTransportAdminMessage.MessagePinned.Action.ValueType  # 0
        PINNED: MiTransportAdminMessage.MessagePinned.Action.ValueType  # 1
        UNPINNED: MiTransportAdminMessage.MessagePinned.Action.ValueType  # 2

        ACTION_FIELD_NUMBER: builtins.int
        action: global___MiTransportAdminMessage.MessagePinned.Action.ValueType
        def __init__(
            self,
            *,
            action: global___MiTransportAdminMessage.MessagePinned.Action.ValueType | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["action", b"action"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["action", b"action"]) -> None: ...

    @typing.final
    class GroupMembershipAddModeChanged(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _Mode:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _ModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MiTransportAdminMessage.GroupMembershipAddModeChanged._Mode.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            UNSET: MiTransportAdminMessage.GroupMembershipAddModeChanged._Mode.ValueType  # 0
            ALL_MEMBERS: MiTransportAdminMessage.GroupMembershipAddModeChanged._Mode.ValueType  # 1
            ADMINS_ONLY: MiTransportAdminMessage.GroupMembershipAddModeChanged._Mode.ValueType  # 2

        class Mode(_Mode, metaclass=_ModeEnumTypeWrapper): ...
        UNSET: MiTransportAdminMessage.GroupMembershipAddModeChanged.Mode.ValueType  # 0
        ALL_MEMBERS: MiTransportAdminMessage.GroupMembershipAddModeChanged.Mode.ValueType  # 1
        ADMINS_ONLY: MiTransportAdminMessage.GroupMembershipAddModeChanged.Mode.ValueType  # 2

        MODE_FIELD_NUMBER: builtins.int
        mode: global___MiTransportAdminMessage.GroupMembershipAddModeChanged.Mode.ValueType
        def __init__(
            self,
            *,
            mode: global___MiTransportAdminMessage.GroupMembershipAddModeChanged.Mode.ValueType | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["mode", b"mode"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["mode", b"mode"]) -> None: ...

    @typing.final
    class GroupAdminChanged(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _Action:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _ActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MiTransportAdminMessage.GroupAdminChanged._Action.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            UNSET: MiTransportAdminMessage.GroupAdminChanged._Action.ValueType  # 0
            ADDED: MiTransportAdminMessage.GroupAdminChanged._Action.ValueType  # 1
            REMOVED: MiTransportAdminMessage.GroupAdminChanged._Action.ValueType  # 2

        class Action(_Action, metaclass=_ActionEnumTypeWrapper): ...
        UNSET: MiTransportAdminMessage.GroupAdminChanged.Action.ValueType  # 0
        ADDED: MiTransportAdminMessage.GroupAdminChanged.Action.ValueType  # 1
        REMOVED: MiTransportAdminMessage.GroupAdminChanged.Action.ValueType  # 2

        TARGETUSERID_FIELD_NUMBER: builtins.int
        ACTION_FIELD_NUMBER: builtins.int
        action: global___MiTransportAdminMessage.GroupAdminChanged.Action.ValueType
        @property
        def targetUserID(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
        def __init__(
            self,
            *,
            targetUserID: collections.abc.Iterable[builtins.str] | None = ...,
            action: global___MiTransportAdminMessage.GroupAdminChanged.Action.ValueType | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["action", b"action"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["action", b"action", "targetUserID", b"targetUserID"]) -> None: ...

    @typing.final
    class GroupParticipantChanged(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _Action:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _ActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MiTransportAdminMessage.GroupParticipantChanged._Action.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            UNSET: MiTransportAdminMessage.GroupParticipantChanged._Action.ValueType  # 0
            ADDED: MiTransportAdminMessage.GroupParticipantChanged._Action.ValueType  # 1
            REMOVED: MiTransportAdminMessage.GroupParticipantChanged._Action.ValueType  # 2

        class Action(_Action, metaclass=_ActionEnumTypeWrapper): ...
        UNSET: MiTransportAdminMessage.GroupParticipantChanged.Action.ValueType  # 0
        ADDED: MiTransportAdminMessage.GroupParticipantChanged.Action.ValueType  # 1
        REMOVED: MiTransportAdminMessage.GroupParticipantChanged.Action.ValueType  # 2

        TARGETUSERID_FIELD_NUMBER: builtins.int
        ACTION_FIELD_NUMBER: builtins.int
        action: global___MiTransportAdminMessage.GroupParticipantChanged.Action.ValueType
        @property
        def targetUserID(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
        def __init__(
            self,
            *,
            targetUserID: collections.abc.Iterable[builtins.str] | None = ...,
            action: global___MiTransportAdminMessage.GroupParticipantChanged.Action.ValueType | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["action", b"action"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["action", b"action", "targetUserID", b"targetUserID"]) -> None: ...

    @typing.final
    class XmatUnpinMessageV2(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        PINNEDMESSAGEID_FIELD_NUMBER: builtins.int
        pinnedMessageID: builtins.str
        def __init__(
            self,
            *,
            pinnedMessageID: builtins.str | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["pinnedMessageID", b"pinnedMessageID"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["pinnedMessageID", b"pinnedMessageID"]) -> None: ...

    @typing.final
    class XmatPinMessageV2(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        PINNEDMESSAGEID_FIELD_NUMBER: builtins.int
        pinnedMessageID: builtins.str
        def __init__(
            self,
            *,
            pinnedMessageID: builtins.str | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["pinnedMessageID", b"pinnedMessageID"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["pinnedMessageID", b"pinnedMessageID"]) -> None: ...

    @typing.final
    class XmatUpdatePayments(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        RECEIVERNAME_FIELD_NUMBER: builtins.int
        SENDERNAME_FIELD_NUMBER: builtins.int
        AMOUNT_FIELD_NUMBER: builtins.int
        TRANSACTIONID_FIELD_NUMBER: builtins.int
        TRANSACTIONSTATUS_FIELD_NUMBER: builtins.int
        receiverName: builtins.str
        senderName: builtins.str
        amount: builtins.float
        transactionID: builtins.int
        transactionStatus: builtins.int
        def __init__(
            self,
            *,
            receiverName: builtins.str | None = ...,
            senderName: builtins.str | None = ...,
            amount: builtins.float | None = ...,
            transactionID: builtins.int | None = ...,
            transactionStatus: builtins.int | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["amount", b"amount", "receiverName", b"receiverName", "senderName", b"senderName", "transactionID", b"transactionID", "transactionStatus", b"transactionStatus"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["amount", b"amount", "receiverName", b"receiverName", "senderName", b"senderName", "transactionID", b"transactionID", "transactionStatus", b"transactionStatus"]) -> None: ...

    @typing.final
    class XmatThreadQuickReaction(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        THREADQUICKREACTIONEMOJI_FIELD_NUMBER: builtins.int
        THREADQUICKREACTIONINSTRUCTIONKEYID_FIELD_NUMBER: builtins.int
        threadQuickReactionEmoji: builtins.str
        threadQuickReactionInstructionKeyID: builtins.str
        def __init__(
            self,
            *,
            threadQuickReactionEmoji: builtins.str | None = ...,
            threadQuickReactionInstructionKeyID: builtins.str | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["threadQuickReactionEmoji", b"threadQuickReactionEmoji", "threadQuickReactionInstructionKeyID", b"threadQuickReactionInstructionKeyID"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["threadQuickReactionEmoji", b"threadQuickReactionEmoji", "threadQuickReactionInstructionKeyID", b"threadQuickReactionInstructionKeyID"]) -> None: ...

    @typing.final
    class XmatThreadNickname(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        PARTICIPANTID_FIELD_NUMBER: builtins.int
        NICKNAME_FIELD_NUMBER: builtins.int
        participantID: builtins.int
        nickname: builtins.str
        def __init__(
            self,
            *,
            participantID: builtins.int | None = ...,
            nickname: builtins.str | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["nickname", b"nickname", "participantID", b"participantID"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["nickname", b"nickname", "participantID", b"participantID"]) -> None: ...

    @typing.final
    class XmatThreadIcon(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        THREADICON_FIELD_NUMBER: builtins.int
        threadIcon: builtins.str
        def __init__(
            self,
            *,
            threadIcon: builtins.str | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["threadIcon", b"threadIcon"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["threadIcon", b"threadIcon"]) -> None: ...

    @typing.final
    class XmatThemeColor(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        THEMEID_FIELD_NUMBER: builtins.int
        THEMECOLOR_FIELD_NUMBER: builtins.int
        GRADIENT_FIELD_NUMBER: builtins.int
        SHOULDSHOWICON_FIELD_NUMBER: builtins.int
        THEMETYPE_FIELD_NUMBER: builtins.int
        ACCESSIBILITYLABEL_FIELD_NUMBER: builtins.int
        THEMENAMEWITHSUBTITLE_FIELD_NUMBER: builtins.int
        THEMEEMOJI_FIELD_NUMBER: builtins.int
        themeID: builtins.str
        themeColor: builtins.str
        shouldShowIcon: builtins.bool
        themeType: builtins.int
        accessibilityLabel: builtins.str
        themeNameWithSubtitle: builtins.str
        themeEmoji: builtins.str
        @property
        def gradient(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
        def __init__(
            self,
            *,
            themeID: builtins.str | None = ...,
            themeColor: builtins.str | None = ...,
            gradient: collections.abc.Iterable[builtins.str] | None = ...,
            shouldShowIcon: builtins.bool | None = ...,
            themeType: builtins.int | None = ...,
            accessibilityLabel: builtins.str | None = ...,
            themeNameWithSubtitle: builtins.str | None = ...,
            themeEmoji: builtins.str | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["accessibilityLabel", b"accessibilityLabel", "shouldShowIcon", b"shouldShowIcon", "themeColor", b"themeColor", "themeEmoji", b"themeEmoji", "themeID", b"themeID", "themeNameWithSubtitle", b"themeNameWithSubtitle", "themeType", b"themeType"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["accessibilityLabel", b"accessibilityLabel", "gradient", b"gradient", "shouldShowIcon", b"shouldShowIcon", "themeColor", b"themeColor", "themeEmoji", b"themeEmoji", "themeID", b"themeID", "themeNameWithSubtitle", b"themeNameWithSubtitle", "themeType", b"themeType"]) -> None: ...

    @typing.final
    class XmatMessengerSharedAlbum(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        XMADATACLASS_FIELD_NUMBER: builtins.int
        xmaDataclass: builtins.str
        def __init__(
            self,
            *,
            xmaDataclass: builtins.str | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["xmaDataclass", b"xmaDataclass"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["xmaDataclass", b"xmaDataclass"]) -> None: ...

    @typing.final
    class XmatMessengerSharedAlbumRename(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        SHAREDALBUMID_FIELD_NUMBER: builtins.int
        OLDALBUMTITLE_FIELD_NUMBER: builtins.int
        NEWALBUMTITLE_FIELD_NUMBER: builtins.int
        sharedAlbumID: builtins.int
        oldAlbumTitle: builtins.str
        newAlbumTitle: builtins.str
        def __init__(
            self,
            *,
            sharedAlbumID: builtins.int | None = ...,
            oldAlbumTitle: builtins.str | None = ...,
            newAlbumTitle: builtins.str | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["newAlbumTitle", b"newAlbumTitle", "oldAlbumTitle", b"oldAlbumTitle", "sharedAlbumID", b"sharedAlbumID"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["newAlbumTitle", b"newAlbumTitle", "oldAlbumTitle", b"oldAlbumTitle", "sharedAlbumID", b"sharedAlbumID"]) -> None: ...

    @typing.final
    class XmatMessengerSharedAlbumDeletion(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        SHAREDALBUMID_FIELD_NUMBER: builtins.int
        ALBUMTITLE_FIELD_NUMBER: builtins.int
        sharedAlbumID: builtins.int
        albumTitle: builtins.str
        def __init__(
            self,
            *,
            sharedAlbumID: builtins.int | None = ...,
            albumTitle: builtins.str | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["albumTitle", b"albumTitle", "sharedAlbumID", b"sharedAlbumID"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["albumTitle", b"albumTitle", "sharedAlbumID", b"sharedAlbumID"]) -> None: ...

    @typing.final
    class XmatMessengerSharedAlbumContentRemoval(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class RemovedContentTuple(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            KEY_FIELD_NUMBER: builtins.int
            VALUE_FIELD_NUMBER: builtins.int
            key: builtins.int
            value: builtins.str
            def __init__(
                self,
                *,
                key: builtins.int | None = ...,
                value: builtins.str | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

        SHAREDALBUMID_FIELD_NUMBER: builtins.int
        REMOVEDCONTENTMAP_FIELD_NUMBER: builtins.int
        REMOVEDCONTENTCOUNT_FIELD_NUMBER: builtins.int
        ALBUMTITLE_FIELD_NUMBER: builtins.int
        sharedAlbumID: builtins.int
        removedContentCount: builtins.int
        albumTitle: builtins.str
        @property
        def removedContentMap(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MiTransportAdminMessage.XmatMessengerSharedAlbumContentRemoval.RemovedContentTuple]: ...
        def __init__(
            self,
            *,
            sharedAlbumID: builtins.int | None = ...,
            removedContentMap: collections.abc.Iterable[global___MiTransportAdminMessage.XmatMessengerSharedAlbumContentRemoval.RemovedContentTuple] | None = ...,
            removedContentCount: builtins.int | None = ...,
            albumTitle: builtins.str | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["albumTitle", b"albumTitle", "removedContentCount", b"removedContentCount", "sharedAlbumID", b"sharedAlbumID"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["albumTitle", b"albumTitle", "removedContentCount", b"removedContentCount", "removedContentMap", b"removedContentMap", "sharedAlbumID", b"sharedAlbumID"]) -> None: ...

    @typing.final
    class XmatMessengerSharedAlbumAddition(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        SHAREDALBUMID_FIELD_NUMBER: builtins.int
        ALBUMTITLE_FIELD_NUMBER: builtins.int
        NUMOFATTACHMENTS_FIELD_NUMBER: builtins.int
        ISALBUMCREATION_FIELD_NUMBER: builtins.int
        sharedAlbumID: builtins.int
        albumTitle: builtins.str
        numOfAttachments: builtins.int
        isAlbumCreation: builtins.bool
        def __init__(
            self,
            *,
            sharedAlbumID: builtins.int | None = ...,
            albumTitle: builtins.str | None = ...,
            numOfAttachments: builtins.int | None = ...,
            isAlbumCreation: builtins.bool | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["albumTitle", b"albumTitle", "isAlbumCreation", b"isAlbumCreation", "numOfAttachments", b"numOfAttachments", "sharedAlbumID", b"sharedAlbumID"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["albumTitle", b"albumTitle", "isAlbumCreation", b"isAlbumCreation", "numOfAttachments", b"numOfAttachments", "sharedAlbumID", b"sharedAlbumID"]) -> None: ...

    @typing.final
    class XmatMessengerQRCodeScanned(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        RECEIVERNAME_FIELD_NUMBER: builtins.int
        SENDERNAME_FIELD_NUMBER: builtins.int
        receiverName: builtins.str
        senderName: builtins.str
        def __init__(
            self,
            *,
            receiverName: builtins.str | None = ...,
            senderName: builtins.str | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["receiverName", b"receiverName", "senderName", b"senderName"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["receiverName", b"receiverName", "senderName", b"senderName"]) -> None: ...

    @typing.final
    class XmatMessagingLimitSharing(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        SENDERNAME_FIELD_NUMBER: builtins.int
        SENDERID_FIELD_NUMBER: builtins.int
        LIMITSHARINGTYPE_FIELD_NUMBER: builtins.int
        senderName: builtins.str
        senderID: builtins.str
        limitSharingType: builtins.str
        def __init__(
            self,
            *,
            senderName: builtins.str | None = ...,
            senderID: builtins.str | None = ...,
            limitSharingType: builtins.str | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["limitSharingType", b"limitSharingType", "senderID", b"senderID", "senderName", b"senderName"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["limitSharingType", b"limitSharingType", "senderID", b"senderID", "senderName", b"senderName"]) -> None: ...

    @typing.final
    class XmatMagicWords(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NEWMAGICWORDCOUNT_FIELD_NUMBER: builtins.int
        REMOVEDMAGICWORDCOUNT_FIELD_NUMBER: builtins.int
        MAGICWORD_FIELD_NUMBER: builtins.int
        EMOJIEFFECT_FIELD_NUMBER: builtins.int
        ISALLEDITED_FIELD_NUMBER: builtins.int
        THEMENAME_FIELD_NUMBER: builtins.int
        newMagicWordCount: builtins.int
        removedMagicWordCount: builtins.int
        magicWord: builtins.str
        emojiEffect: builtins.str
        isAllEdited: builtins.bool
        themeName: builtins.str
        def __init__(
            self,
            *,
            newMagicWordCount: builtins.int | None = ...,
            removedMagicWordCount: builtins.int | None = ...,
            magicWord: builtins.str | None = ...,
            emojiEffect: builtins.str | None = ...,
            isAllEdited: builtins.bool | None = ...,
            themeName: builtins.str | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["emojiEffect", b"emojiEffect", "isAllEdited", b"isAllEdited", "magicWord", b"magicWord", "newMagicWordCount", b"newMagicWordCount", "removedMagicWordCount", b"removedMagicWordCount", "themeName", b"themeName"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["emojiEffect", b"emojiEffect", "isAllEdited", b"isAllEdited", "magicWord", b"magicWord", "newMagicWordCount", b"newMagicWordCount", "removedMagicWordCount", b"removedMagicWordCount", "themeName", b"themeName"]) -> None: ...

    @typing.final
    class XmatLinkCTA(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        LINKCTAXMATPRIMARYTEXT_FIELD_NUMBER: builtins.int
        LINKCTAXMATCTATEXT_FIELD_NUMBER: builtins.int
        LINKCTAXMATCTAURL_FIELD_NUMBER: builtins.int
        LINKCTAXMATCTAIOSURL_FIELD_NUMBER: builtins.int
        ANDROIDURI_FIELD_NUMBER: builtins.int
        ASYNCURL_FIELD_NUMBER: builtins.int
        WWWISASYNCURL_FIELD_NUMBER: builtins.int
        MSITEENABLED_FIELD_NUMBER: builtins.int
        HIDEURIINFALLBACK_FIELD_NUMBER: builtins.int
        SHOWCONFIRMATIONDIALOG_FIELD_NUMBER: builtins.int
        GRAPHPAYLOAD_FIELD_NUMBER: builtins.int
        IDENTIFIERNAME_FIELD_NUMBER: builtins.int
        THREADID_FIELD_NUMBER: builtins.int
        HIDECTAINFALLBACK_FIELD_NUMBER: builtins.int
        CTXADCONVERSATIONSTARTERINFO_FIELD_NUMBER: builtins.int
        FBMURI_FIELD_NUMBER: builtins.int
        INITIATORUSERID_FIELD_NUMBER: builtins.int
        linkCtaXmatPrimaryText: builtins.str
        linkCtaXmatCtaText: builtins.str
        linkCtaXmatCtaURL: builtins.str
        linkCtaXmatCtaIosURL: builtins.str
        androidUri: builtins.str
        asyncURL: builtins.str
        wwwIsAsyncURL: builtins.bool
        msiteEnabled: builtins.bool
        hideUriInFallback: builtins.bool
        showConfirmationDialog: builtins.bool
        graphPayload: builtins.str
        identifierName: builtins.str
        threadID: builtins.str
        hideCtaInFallback: builtins.bool
        ctxAdConversationStarterInfo: builtins.str
        fbmUri: builtins.str
        initiatorUserID: builtins.str
        def __init__(
            self,
            *,
            linkCtaXmatPrimaryText: builtins.str | None = ...,
            linkCtaXmatCtaText: builtins.str | None = ...,
            linkCtaXmatCtaURL: builtins.str | None = ...,
            linkCtaXmatCtaIosURL: builtins.str | None = ...,
            androidUri: builtins.str | None = ...,
            asyncURL: builtins.str | None = ...,
            wwwIsAsyncURL: builtins.bool | None = ...,
            msiteEnabled: builtins.bool | None = ...,
            hideUriInFallback: builtins.bool | None = ...,
            showConfirmationDialog: builtins.bool | None = ...,
            graphPayload: builtins.str | None = ...,
            identifierName: builtins.str | None = ...,
            threadID: builtins.str | None = ...,
            hideCtaInFallback: builtins.bool | None = ...,
            ctxAdConversationStarterInfo: builtins.str | None = ...,
            fbmUri: builtins.str | None = ...,
            initiatorUserID: builtins.str | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["androidUri", b"androidUri", "asyncURL", b"asyncURL", "ctxAdConversationStarterInfo", b"ctxAdConversationStarterInfo", "fbmUri", b"fbmUri", "graphPayload", b"graphPayload", "hideCtaInFallback", b"hideCtaInFallback", "hideUriInFallback", b"hideUriInFallback", "identifierName", b"identifierName", "initiatorUserID", b"initiatorUserID", "linkCtaXmatCtaIosURL", b"linkCtaXmatCtaIosURL", "linkCtaXmatCtaText", b"linkCtaXmatCtaText", "linkCtaXmatCtaURL", b"linkCtaXmatCtaURL", "linkCtaXmatPrimaryText", b"linkCtaXmatPrimaryText", "msiteEnabled", b"msiteEnabled", "showConfirmationDialog", b"showConfirmationDialog", "threadID", b"threadID", "wwwIsAsyncURL", b"wwwIsAsyncURL"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["androidUri", b"androidUri", "asyncURL", b"asyncURL", "ctxAdConversationStarterInfo", b"ctxAdConversationStarterInfo", "fbmUri", b"fbmUri", "graphPayload", b"graphPayload", "hideCtaInFallback", b"hideCtaInFallback", "hideUriInFallback", b"hideUriInFallback", "identifierName", b"identifierName", "initiatorUserID", b"initiatorUserID", "linkCtaXmatCtaIosURL", b"linkCtaXmatCtaIosURL", "linkCtaXmatCtaText", b"linkCtaXmatCtaText", "linkCtaXmatCtaURL", b"linkCtaXmatCtaURL", "linkCtaXmatPrimaryText", b"linkCtaXmatPrimaryText", "msiteEnabled", b"msiteEnabled", "showConfirmationDialog", b"showConfirmationDialog", "threadID", b"threadID", "wwwIsAsyncURL", b"wwwIsAsyncURL"]) -> None: ...

    @typing.final
    class XmatInstantGameEncryptedDynamicCustomUpdate(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        SENDERNAME_FIELD_NUMBER: builtins.int
        MUTEMANAGEMENTADMINTEXTTYPE_FIELD_NUMBER: builtins.int
        GAMENAME_FIELD_NUMBER: builtins.int
        senderName: builtins.str
        muteManagementAdminTextType: builtins.str
        gameName: builtins.str
        def __init__(
            self,
            *,
            senderName: builtins.str | None = ...,
            muteManagementAdminTextType: builtins.str | None = ...,
            gameName: builtins.str | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["gameName", b"gameName", "muteManagementAdminTextType", b"muteManagementAdminTextType", "senderName", b"senderName"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["gameName", b"gameName", "muteManagementAdminTextType", b"muteManagementAdminTextType", "senderName", b"senderName"]) -> None: ...

    @typing.final
    class XmatFriendRequestConfirmedEncrypted(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        OTHERUSERNAME_FIELD_NUMBER: builtins.int
        ISTURNONCOHORT_FIELD_NUMBER: builtins.int
        otherUserName: builtins.str
        isTurnOnCohort: builtins.str
        def __init__(
            self,
            *,
            otherUserName: builtins.str | None = ...,
            isTurnOnCohort: builtins.str | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["isTurnOnCohort", b"isTurnOnCohort", "otherUserName", b"otherUserName"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["isTurnOnCohort", b"isTurnOnCohort", "otherUserName", b"otherUserName"]) -> None: ...

    @typing.final
    class XmatDisappearingSetting(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        DISAPPEARINGSETTINGTIME_FIELD_NUMBER: builtins.int
        OLDDISAPPEARINGSETTINGTIME_FIELD_NUMBER: builtins.int
        DISAPPEARINGSETTINGACTORFBID_FIELD_NUMBER: builtins.int
        NEWEPHEMERALITYTYPE_FIELD_NUMBER: builtins.int
        OLDEPHEMERALITYTYPE_FIELD_NUMBER: builtins.int
        disappearingSettingTime: builtins.int
        oldDisappearingSettingTime: builtins.int
        disappearingSettingActorFbid: builtins.int
        newEphemeralityType: builtins.int
        oldEphemeralityType: builtins.int
        def __init__(
            self,
            *,
            disappearingSettingTime: builtins.int | None = ...,
            oldDisappearingSettingTime: builtins.int | None = ...,
            disappearingSettingActorFbid: builtins.int | None = ...,
            newEphemeralityType: builtins.int | None = ...,
            oldEphemeralityType: builtins.int | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["disappearingSettingActorFbid", b"disappearingSettingActorFbid", "disappearingSettingTime", b"disappearingSettingTime", "newEphemeralityType", b"newEphemeralityType", "oldDisappearingSettingTime", b"oldDisappearingSettingTime", "oldEphemeralityType", b"oldEphemeralityType"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["disappearingSettingActorFbid", b"disappearingSettingActorFbid", "disappearingSettingTime", b"disappearingSettingTime", "newEphemeralityType", b"newEphemeralityType", "oldDisappearingSettingTime", b"oldDisappearingSettingTime", "oldEphemeralityType", b"oldEphemeralityType"]) -> None: ...

    @typing.final
    class DisappearingSettingChanged(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        DISAPPEARINGSETTINGDURATIONSECONDS_FIELD_NUMBER: builtins.int
        OLDDISAPPEARINGSETTINGDURATIONSECONDS_FIELD_NUMBER: builtins.int
        disappearingSettingDurationSeconds: builtins.int
        oldDisappearingSettingDurationSeconds: builtins.int
        def __init__(
            self,
            *,
            disappearingSettingDurationSeconds: builtins.int | None = ...,
            oldDisappearingSettingDurationSeconds: builtins.int | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["disappearingSettingDurationSeconds", b"disappearingSettingDurationSeconds", "oldDisappearingSettingDurationSeconds", b"oldDisappearingSettingDurationSeconds"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["disappearingSettingDurationSeconds", b"disappearingSettingDurationSeconds", "oldDisappearingSettingDurationSeconds", b"oldDisappearingSettingDurationSeconds"]) -> None: ...

    @typing.final
    class IconChanged(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        THREADICON_FIELD_NUMBER: builtins.int
        threadIcon: builtins.str
        def __init__(
            self,
            *,
            threadIcon: builtins.str | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["threadIcon", b"threadIcon"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["threadIcon", b"threadIcon"]) -> None: ...

    @typing.final
    class LinkCta(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class UkOsaAdminText(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            INITIATORUSERID_FIELD_NUMBER: builtins.int
            initiatorUserID: builtins.str
            def __init__(
                self,
                *,
                initiatorUserID: builtins.str | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["initiatorUserID", b"initiatorUserID"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["initiatorUserID", b"initiatorUserID"]) -> None: ...

        UKOSAADMINTEXT_FIELD_NUMBER: builtins.int
        @property
        def ukOsaAdminText(self) -> global___MiTransportAdminMessage.LinkCta.UkOsaAdminText: ...
        def __init__(
            self,
            *,
            ukOsaAdminText: global___MiTransportAdminMessage.LinkCta.UkOsaAdminText | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["content", b"content", "ukOsaAdminText", b"ukOsaAdminText"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["content", b"content", "ukOsaAdminText", b"ukOsaAdminText"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["content", b"content"]) -> typing.Literal["ukOsaAdminText"] | None: ...

    @typing.final
    class QuickReactionChanged(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        EMOJINAME_FIELD_NUMBER: builtins.int
        emojiName: builtins.str
        def __init__(
            self,
            *,
            emojiName: builtins.str | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["emojiName", b"emojiName"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["emojiName", b"emojiName"]) -> None: ...

    @typing.final
    class GroupNameChanged(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        GROUPNAME_FIELD_NUMBER: builtins.int
        groupName: builtins.str
        def __init__(
            self,
            *,
            groupName: builtins.str | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["groupName", b"groupName"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["groupName", b"groupName"]) -> None: ...

    @typing.final
    class NicknameChanged(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TARGETUSERID_FIELD_NUMBER: builtins.int
        NICKNAME_FIELD_NUMBER: builtins.int
        targetUserID: builtins.str
        nickname: builtins.str
        def __init__(
            self,
            *,
            targetUserID: builtins.str | None = ...,
            nickname: builtins.str | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["nickname", b"nickname", "targetUserID", b"targetUserID"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["nickname", b"nickname", "targetUserID", b"targetUserID"]) -> None: ...

    @typing.final
    class ChatThemeChanged(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        THEMENAME_FIELD_NUMBER: builtins.int
        THEMEEMOJI_FIELD_NUMBER: builtins.int
        THEMETYPE_FIELD_NUMBER: builtins.int
        themeName: builtins.str
        themeEmoji: builtins.str
        themeType: builtins.int
        def __init__(
            self,
            *,
            themeName: builtins.str | None = ...,
            themeEmoji: builtins.str | None = ...,
            themeType: builtins.int | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["themeEmoji", b"themeEmoji", "themeName", b"themeName", "themeType", b"themeType"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["themeEmoji", b"themeEmoji", "themeName", b"themeName", "themeType", b"themeType"]) -> None: ...

    CHATTHEMECHANGED_FIELD_NUMBER: builtins.int
    NICKNAMECHANGED_FIELD_NUMBER: builtins.int
    GROUPPARTICIPANTCHANGED_FIELD_NUMBER: builtins.int
    GROUPADMINCHANGED_FIELD_NUMBER: builtins.int
    GROUPNAMECHANGED_FIELD_NUMBER: builtins.int
    GROUPMEMBERSHIPADDMODECHANGED_FIELD_NUMBER: builtins.int
    MESSAGEPINNED_FIELD_NUMBER: builtins.int
    GROUPIMAGECHANGED_FIELD_NUMBER: builtins.int
    QUICKREACTIONCHANGED_FIELD_NUMBER: builtins.int
    LINKCTA_FIELD_NUMBER: builtins.int
    ICONCHANGED_FIELD_NUMBER: builtins.int
    DISAPPEARINGSETTINGCHANGED_FIELD_NUMBER: builtins.int
    LIMITSHARINGCHANGED_FIELD_NUMBER: builtins.int
    XMATDISAPPEARINGSETTING_FIELD_NUMBER: builtins.int
    XMATFRIENDREQUESTCONFIRMEDENCRYPTED_FIELD_NUMBER: builtins.int
    XMATINSTANTGAMEENCRYPTEDDYNAMICCUSTOMUPDATE_FIELD_NUMBER: builtins.int
    XMATLINKCTA_FIELD_NUMBER: builtins.int
    XMATMAGICWORDS_FIELD_NUMBER: builtins.int
    XMATMESSAGINGLIMITSHARING_FIELD_NUMBER: builtins.int
    XMATMESSENGERQRCODESCANNED_FIELD_NUMBER: builtins.int
    XMATMESSENGERSHAREDALBUMADDITION_FIELD_NUMBER: builtins.int
    XMATMESSENGERSHAREDALBUMCONTENTREMOVAL_FIELD_NUMBER: builtins.int
    XMATMESSENGERSHAREDALBUMDELETION_FIELD_NUMBER: builtins.int
    XMATMESSENGERSHAREDALBUMRENAME_FIELD_NUMBER: builtins.int
    XMATMESSENGERSHAREDALBUM_FIELD_NUMBER: builtins.int
    XMATTHEMECOLOR_FIELD_NUMBER: builtins.int
    XMATTHREADICON_FIELD_NUMBER: builtins.int
    XMATTHREADNICKNAME_FIELD_NUMBER: builtins.int
    XMATTHREADQUICKREACTION_FIELD_NUMBER: builtins.int
    XMATUPDATEPAYMENTS_FIELD_NUMBER: builtins.int
    XMATPINMESSAGEV2_FIELD_NUMBER: builtins.int
    XMATUNPINMESSAGEV2_FIELD_NUMBER: builtins.int
    @property
    def chatThemeChanged(self) -> global___MiTransportAdminMessage.ChatThemeChanged: ...
    @property
    def nicknameChanged(self) -> global___MiTransportAdminMessage.NicknameChanged: ...
    @property
    def groupParticipantChanged(self) -> global___MiTransportAdminMessage.GroupParticipantChanged: ...
    @property
    def groupAdminChanged(self) -> global___MiTransportAdminMessage.GroupAdminChanged: ...
    @property
    def groupNameChanged(self) -> global___MiTransportAdminMessage.GroupNameChanged: ...
    @property
    def groupMembershipAddModeChanged(self) -> global___MiTransportAdminMessage.GroupMembershipAddModeChanged: ...
    @property
    def messagePinned(self) -> global___MiTransportAdminMessage.MessagePinned: ...
    @property
    def groupImageChanged(self) -> global___MiTransportAdminMessage.GroupImageChanged: ...
    @property
    def quickReactionChanged(self) -> global___MiTransportAdminMessage.QuickReactionChanged: ...
    @property
    def linkCta(self) -> global___MiTransportAdminMessage.LinkCta: ...
    @property
    def iconChanged(self) -> global___MiTransportAdminMessage.IconChanged: ...
    @property
    def disappearingSettingChanged(self) -> global___MiTransportAdminMessage.DisappearingSettingChanged: ...
    @property
    def limitSharingChanged(self) -> global___MiTransportAdminMessage.LimitSharingChanged: ...
    @property
    def xmatDisappearingSetting(self) -> global___MiTransportAdminMessage.XmatDisappearingSetting: ...
    @property
    def xmatFriendRequestConfirmedEncrypted(self) -> global___MiTransportAdminMessage.XmatFriendRequestConfirmedEncrypted: ...
    @property
    def xmatInstantGameEncryptedDynamicCustomUpdate(self) -> global___MiTransportAdminMessage.XmatInstantGameEncryptedDynamicCustomUpdate: ...
    @property
    def xmatLinkCta(self) -> global___MiTransportAdminMessage.XmatLinkCTA: ...
    @property
    def xmatMagicWords(self) -> global___MiTransportAdminMessage.XmatMagicWords: ...
    @property
    def xmatMessagingLimitSharing(self) -> global___MiTransportAdminMessage.XmatMessagingLimitSharing: ...
    @property
    def xmatMessengerQrCodeScanned(self) -> global___MiTransportAdminMessage.XmatMessengerQRCodeScanned: ...
    @property
    def xmatMessengerSharedAlbumAddition(self) -> global___MiTransportAdminMessage.XmatMessengerSharedAlbumAddition: ...
    @property
    def xmatMessengerSharedAlbumContentRemoval(self) -> global___MiTransportAdminMessage.XmatMessengerSharedAlbumContentRemoval: ...
    @property
    def xmatMessengerSharedAlbumDeletion(self) -> global___MiTransportAdminMessage.XmatMessengerSharedAlbumDeletion: ...
    @property
    def xmatMessengerSharedAlbumRename(self) -> global___MiTransportAdminMessage.XmatMessengerSharedAlbumRename: ...
    @property
    def xmatMessengerSharedAlbum(self) -> global___MiTransportAdminMessage.XmatMessengerSharedAlbum: ...
    @property
    def xmatThemeColor(self) -> global___MiTransportAdminMessage.XmatThemeColor: ...
    @property
    def xmatThreadIcon(self) -> global___MiTransportAdminMessage.XmatThreadIcon: ...
    @property
    def xmatThreadNickname(self) -> global___MiTransportAdminMessage.XmatThreadNickname: ...
    @property
    def xmatThreadQuickReaction(self) -> global___MiTransportAdminMessage.XmatThreadQuickReaction: ...
    @property
    def xmatUpdatePayments(self) -> global___MiTransportAdminMessage.XmatUpdatePayments: ...
    @property
    def xmatPinMessageV2(self) -> global___MiTransportAdminMessage.XmatPinMessageV2: ...
    @property
    def xmatUnpinMessageV2(self) -> global___MiTransportAdminMessage.XmatUnpinMessageV2: ...
    def __init__(
        self,
        *,
        chatThemeChanged: global___MiTransportAdminMessage.ChatThemeChanged | None = ...,
        nicknameChanged: global___MiTransportAdminMessage.NicknameChanged | None = ...,
        groupParticipantChanged: global___MiTransportAdminMessage.GroupParticipantChanged | None = ...,
        groupAdminChanged: global___MiTransportAdminMessage.GroupAdminChanged | None = ...,
        groupNameChanged: global___MiTransportAdminMessage.GroupNameChanged | None = ...,
        groupMembershipAddModeChanged: global___MiTransportAdminMessage.GroupMembershipAddModeChanged | None = ...,
        messagePinned: global___MiTransportAdminMessage.MessagePinned | None = ...,
        groupImageChanged: global___MiTransportAdminMessage.GroupImageChanged | None = ...,
        quickReactionChanged: global___MiTransportAdminMessage.QuickReactionChanged | None = ...,
        linkCta: global___MiTransportAdminMessage.LinkCta | None = ...,
        iconChanged: global___MiTransportAdminMessage.IconChanged | None = ...,
        disappearingSettingChanged: global___MiTransportAdminMessage.DisappearingSettingChanged | None = ...,
        limitSharingChanged: global___MiTransportAdminMessage.LimitSharingChanged | None = ...,
        xmatDisappearingSetting: global___MiTransportAdminMessage.XmatDisappearingSetting | None = ...,
        xmatFriendRequestConfirmedEncrypted: global___MiTransportAdminMessage.XmatFriendRequestConfirmedEncrypted | None = ...,
        xmatInstantGameEncryptedDynamicCustomUpdate: global___MiTransportAdminMessage.XmatInstantGameEncryptedDynamicCustomUpdate | None = ...,
        xmatLinkCta: global___MiTransportAdminMessage.XmatLinkCTA | None = ...,
        xmatMagicWords: global___MiTransportAdminMessage.XmatMagicWords | None = ...,
        xmatMessagingLimitSharing: global___MiTransportAdminMessage.XmatMessagingLimitSharing | None = ...,
        xmatMessengerQrCodeScanned: global___MiTransportAdminMessage.XmatMessengerQRCodeScanned | None = ...,
        xmatMessengerSharedAlbumAddition: global___MiTransportAdminMessage.XmatMessengerSharedAlbumAddition | None = ...,
        xmatMessengerSharedAlbumContentRemoval: global___MiTransportAdminMessage.XmatMessengerSharedAlbumContentRemoval | None = ...,
        xmatMessengerSharedAlbumDeletion: global___MiTransportAdminMessage.XmatMessengerSharedAlbumDeletion | None = ...,
        xmatMessengerSharedAlbumRename: global___MiTransportAdminMessage.XmatMessengerSharedAlbumRename | None = ...,
        xmatMessengerSharedAlbum: global___MiTransportAdminMessage.XmatMessengerSharedAlbum | None = ...,
        xmatThemeColor: global___MiTransportAdminMessage.XmatThemeColor | None = ...,
        xmatThreadIcon: global___MiTransportAdminMessage.XmatThreadIcon | None = ...,
        xmatThreadNickname: global___MiTransportAdminMessage.XmatThreadNickname | None = ...,
        xmatThreadQuickReaction: global___MiTransportAdminMessage.XmatThreadQuickReaction | None = ...,
        xmatUpdatePayments: global___MiTransportAdminMessage.XmatUpdatePayments | None = ...,
        xmatPinMessageV2: global___MiTransportAdminMessage.XmatPinMessageV2 | None = ...,
        xmatUnpinMessageV2: global___MiTransportAdminMessage.XmatUnpinMessageV2 | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["chatThemeChanged", b"chatThemeChanged", "content", b"content", "disappearingSettingChanged", b"disappearingSettingChanged", "groupAdminChanged", b"groupAdminChanged", "groupImageChanged", b"groupImageChanged", "groupMembershipAddModeChanged", b"groupMembershipAddModeChanged", "groupNameChanged", b"groupNameChanged", "groupParticipantChanged", b"groupParticipantChanged", "iconChanged", b"iconChanged", "limitSharingChanged", b"limitSharingChanged", "linkCta", b"linkCta", "messagePinned", b"messagePinned", "nicknameChanged", b"nicknameChanged", "quickReactionChanged", b"quickReactionChanged", "xmatDisappearingSetting", b"xmatDisappearingSetting", "xmatFriendRequestConfirmedEncrypted", b"xmatFriendRequestConfirmedEncrypted", "xmatInstantGameEncryptedDynamicCustomUpdate", b"xmatInstantGameEncryptedDynamicCustomUpdate", "xmatLinkCta", b"xmatLinkCta", "xmatMagicWords", b"xmatMagicWords", "xmatMessagingLimitSharing", b"xmatMessagingLimitSharing", "xmatMessengerQrCodeScanned", b"xmatMessengerQrCodeScanned", "xmatMessengerSharedAlbum", b"xmatMessengerSharedAlbum", "xmatMessengerSharedAlbumAddition", b"xmatMessengerSharedAlbumAddition", "xmatMessengerSharedAlbumContentRemoval", b"xmatMessengerSharedAlbumContentRemoval", "xmatMessengerSharedAlbumDeletion", b"xmatMessengerSharedAlbumDeletion", "xmatMessengerSharedAlbumRename", b"xmatMessengerSharedAlbumRename", "xmatPinMessageV2", b"xmatPinMessageV2", "xmatThemeColor", b"xmatThemeColor", "xmatThreadIcon", b"xmatThreadIcon", "xmatThreadNickname", b"xmatThreadNickname", "xmatThreadQuickReaction", b"xmatThreadQuickReaction", "xmatUnpinMessageV2", b"xmatUnpinMessageV2", "xmatUpdatePayments", b"xmatUpdatePayments"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["chatThemeChanged", b"chatThemeChanged", "content", b"content", "disappearingSettingChanged", b"disappearingSettingChanged", "groupAdminChanged", b"groupAdminChanged", "groupImageChanged", b"groupImageChanged", "groupMembershipAddModeChanged", b"groupMembershipAddModeChanged", "groupNameChanged", b"groupNameChanged", "groupParticipantChanged", b"groupParticipantChanged", "iconChanged", b"iconChanged", "limitSharingChanged", b"limitSharingChanged", "linkCta", b"linkCta", "messagePinned", b"messagePinned", "nicknameChanged", b"nicknameChanged", "quickReactionChanged", b"quickReactionChanged", "xmatDisappearingSetting", b"xmatDisappearingSetting", "xmatFriendRequestConfirmedEncrypted", b"xmatFriendRequestConfirmedEncrypted", "xmatInstantGameEncryptedDynamicCustomUpdate", b"xmatInstantGameEncryptedDynamicCustomUpdate", "xmatLinkCta", b"xmatLinkCta", "xmatMagicWords", b"xmatMagicWords", "xmatMessagingLimitSharing", b"xmatMessagingLimitSharing", "xmatMessengerQrCodeScanned", b"xmatMessengerQrCodeScanned", "xmatMessengerSharedAlbum", b"xmatMessengerSharedAlbum", "xmatMessengerSharedAlbumAddition", b"xmatMessengerSharedAlbumAddition", "xmatMessengerSharedAlbumContentRemoval", b"xmatMessengerSharedAlbumContentRemoval", "xmatMessengerSharedAlbumDeletion", b"xmatMessengerSharedAlbumDeletion", "xmatMessengerSharedAlbumRename", b"xmatMessengerSharedAlbumRename", "xmatPinMessageV2", b"xmatPinMessageV2", "xmatThemeColor", b"xmatThemeColor", "xmatThreadIcon", b"xmatThreadIcon", "xmatThreadNickname", b"xmatThreadNickname", "xmatThreadQuickReaction", b"xmatThreadQuickReaction", "xmatUnpinMessageV2", b"xmatUnpinMessageV2", "xmatUpdatePayments", b"xmatUpdatePayments"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["content", b"content"]) -> typing.Literal["chatThemeChanged", "nicknameChanged", "groupParticipantChanged", "groupAdminChanged", "groupNameChanged", "groupMembershipAddModeChanged", "messagePinned", "groupImageChanged", "quickReactionChanged", "linkCta", "iconChanged", "disappearingSettingChanged", "limitSharingChanged", "xmatDisappearingSetting", "xmatFriendRequestConfirmedEncrypted", "xmatInstantGameEncryptedDynamicCustomUpdate", "xmatLinkCta", "xmatMagicWords", "xmatMessagingLimitSharing", "xmatMessengerQrCodeScanned", "xmatMessengerSharedAlbumAddition", "xmatMessengerSharedAlbumContentRemoval", "xmatMessengerSharedAlbumDeletion", "xmatMessengerSharedAlbumRename", "xmatMessengerSharedAlbum", "xmatThemeColor", "xmatThreadIcon", "xmatThreadNickname", "xmatThreadQuickReaction", "xmatUpdatePayments", "xmatPinMessageV2", "xmatUnpinMessageV2"] | None: ...

global___MiTransportAdminMessage = MiTransportAdminMessage



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: instamadilloSupplementMessage/InstamadilloSupplementMessage.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'instamadilloSupplementMessage/InstamadilloSupplementMessage.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from instamadilloCoreTypeMedia import InstamadilloCoreTypeMedia_pb2 as instamadilloCoreTypeMedia_dot_InstamadilloCoreTypeMedia__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAinstamadilloSupplementMessage/InstamadilloSupplementMessage.proto\x12\x1dInstamadilloSupplementMessage\x1a\x39instamadilloCoreTypeMedia/InstamadilloCoreTypeMedia.proto\"\xe7\x01\n\x18SupplementMessagePayload\x12\x19\n\x11targetMessageOtid\x18\x01 \x01(\t\x12&\n\x1euniquingKeyForSupplementalData\x18\x02 \x01(\t\x12H\n\x07\x63ontent\x18\x03 \x01(\x0b\x32\x37.InstamadilloSupplementMessage.SupplementMessageContent\x12$\n\x1ctargetMessageWaServerTimeSec\x18\x04 \x01(\t\x12\x18\n\x10targetWaThreadID\x18\x05 \x01(\t\"\xe8\x03\n\x18SupplementMessageContent\x12;\n\x08reaction\x18\x01 \x01(\x0b\x32\'.InstamadilloSupplementMessage.ReactionH\x00\x12\x41\n\x0b\x63ontentView\x18\x02 \x01(\x0b\x32*.InstamadilloSupplementMessage.ContentViewH\x00\x12;\n\x08\x65\x64itText\x18\x03 \x01(\x0b\x32\'.InstamadilloSupplementMessage.EditTextH\x00\x12\x45\n\rmediaReaction\x18\x04 \x01(\x0b\x32,.InstamadilloSupplementMessage.MediaReactionH\x00\x12[\n\x18originalTransportPayload\x18\x05 \x01(\x0b\x32\x37.InstamadilloSupplementMessage.OriginalTransportPayloadH\x00\x12O\n\x12mediaInterventions\x18\x06 \x01(\x0b\x32\x31.InstamadilloSupplementMessage.MediaInterventionsH\x00\x42\x1a\n\x18supplementMessageContent\"[\n\rMediaReaction\x12\x0f\n\x07mediaID\x18\x01 \x01(\t\x12\x39\n\x08reaction\x18\x02 \x01(\x0b\x32\'.InstamadilloSupplementMessage.Reaction\"v\n\x08Reaction\x12\x14\n\x0creactionType\x18\x01 \x01(\t\x12\x16\n\x0ereactionStatus\x18\x02 \x01(\t\x12\r\n\x05\x65moji\x18\x03 \x01(\t\x12\x16\n\x0esuperReactType\x18\x04 \x01(\t\x12\x15\n\ractionLogOtid\x18\x05 \x01(\t\"h\n\x0b\x43ontentView\x12\x0c\n\x04seen\x18\x01 \x01(\x08\x12\x15\n\rscreenshotted\x18\x02 \x01(\x08\x12\x10\n\x08replayed\x18\x03 \x01(\x08\x12\x10\n\x08mimetype\x18\x04 \x01(\t\x12\x10\n\x08objectID\x18\x05 \x01(\t\"1\n\x08\x45\x64itText\x12\x12\n\nnewContent\x18\x01 \x01(\t\x12\x11\n\teditCount\x18\x02 \x01(\x05\"<\n\x18OriginalTransportPayload\x12 \n\x18originalTransportPayload\x18\x01 \x01(\x0c\"r\n\x12MediaInterventions\x12\x0f\n\x07mediaID\x18\x01 \x01(\t\x12K\n\x10interventionType\x18\x02 \x01(\x0e\x32\x31.InstamadilloCoreTypeMedia.Media.InterventionTypeB9Z7go.mau.fi/whatsmeow/proto/instamadilloSupplementMessage')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'instamadilloSupplementMessage.InstamadilloSupplementMessage_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7go.mau.fi/whatsmeow/proto/instamadilloSupplementMessage'
  _globals['_SUPPLEMENTMESSAGEPAYLOAD']._serialized_start=160
  _globals['_SUPPLEMENTMESSAGEPAYLOAD']._serialized_end=391
  _globals['_SUPPLEMENTMESSAGECONTENT']._serialized_start=394
  _globals['_SUPPLEMENTMESSAGECONTENT']._serialized_end=882
  _globals['_MEDIAREACTION']._serialized_start=884
  _globals['_MEDIAREACTION']._serialized_end=975
  _globals['_REACTION']._serialized_start=977
  _globals['_REACTION']._serialized_end=1095
  _globals['_CONTENTVIEW']._serialized_start=1097
  _globals['_CONTENTVIEW']._serialized_end=1201
  _globals['_EDITTEXT']._serialized_start=1203
  _globals['_EDITTEXT']._serialized_end=1252
  _globals['_ORIGINALTRANSPORTPAYLOAD']._serialized_start=1254
  _globals['_ORIGINALTRANSPORTPAYLOAD']._serialized_end=1314
  _globals['_MEDIAINTERVENTIONS']._serialized_start=1316
  _globals['_MEDIAINTERVENTIONS']._serialized_end=1430
# @@protoc_insertion_point(module_scope)
